# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V34
6102
6103
8252
8254
8263
8266
12293
12294
12316
12317
12347
12349
12443
12447
12448
12449
12539
12540
12541
12543
40981
40982
65108
65110
65306
65308
65381
65382
65438
65440
94176
94180
128633
128636
END
