# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'ToNa1'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'ToNa1'}{'missing'} = ''; # code point maps to the empty string

return <<'END';
0		NULL
1		START OF HEADING
2		START OF TEXT
3		END OF TEXT
4		END OF TRANSMISSION
5		ENQUIRY
6		ACKNOWLEDGE
7		BELL
8		BACKSPACE
9		CHARACTER TABULATION
A		LINE FEED (LF)
B		LINE TABULATION
C		FORM FEED (FF)
D		CARRIAGE RETURN (CR)
E		SHIFT OUT
F		SHIFT IN
10		DATA LINK ESCAPE
11		DEVICE CONTROL ONE
12		DEVICE CONTROL TWO
13		DEVICE CONTROL THREE
14		DEVICE CONTROL FOUR
15		NEGATIVE ACKNOWLEDGE
16		SYNCHRONOUS IDLE
17		END OF TRANSMISSION BLOCK
18		CANCEL
19		END OF MEDIUM
1A		SUBSTITUTE
1B		ESCAPE
1C		INFORMATION SEPARATOR FOUR
1D		INFORMATION SEPARATOR THREE
1E		INFORMATION SEPARATOR TWO
1F		INFORMATION SEPARATOR ONE
27		APOSTROPHE-QUOTE
28		OPENING PARENTHESIS
29		CLOSING PARENTHESIS
2E		PERIOD
2F		SLASH
5B		OPENING SQUARE BRACKET
5C		BACKSLASH
5D		CLOSING SQUARE BRACKET
5E		SPACING CIRCUMFLEX
5F		SPACING UNDERSCORE
60		SPACING GRAVE
7B		OPENING CURLY BRACKET
7C		VERTICAL BAR
7D		CLOSING CURLY BRACKET
7F		DELETE
82		BREAK PERMITTED HERE
83		NO BREAK HERE
85		NEXT LINE (NEL)
86		START OF SELECTED AREA
87		END OF SELECTED AREA
88		CHARACTER TABULATION SET
89		CHARACTER TABULATION WITH JUSTIFICATION
8A		LINE TABULATION SET
8B		PARTIAL LINE FORWARD
8C		PARTIAL LINE BACKWARD
8D		REVERSE LINE FEED
8E		SINGLE SHIFT TWO
8F		SINGLE SHIFT THREE
90		DEVICE CONTROL STRING
91		PRIVATE USE ONE
92		PRIVATE USE TWO
93		SET TRANSMIT STATE
94		CANCEL CHARACTER
95		MESSAGE WAITING
96		START OF GUARDED AREA
97		END OF GUARDED AREA
98		START OF STRING
9A		SINGLE CHARACTER INTRODUCER
9B		CONTROL SEQUENCE INTRODUCER
9C		STRING TERMINATOR
9D		OPERATING SYSTEM COMMAND
9E		PRIVACY MESSAGE
9F		APPLICATION PROGRAM COMMAND
A0		NON-BREAKING SPACE
A6		BROKEN VERTICAL BAR
A8		SPACING DIAERESIS
AB		LEFT POINTING GUILLEMET
AE		REGISTERED TRADE MARK SIGN
AF		SPACING MACRON
B1		PLUS-OR-MINUS SIGN
B2		SUPERSCRIPT DIGIT TWO
B3		SUPERSCRIPT DIGIT THREE
B4		SPACING ACUTE
B6		PARAGRAPH SIGN
B8		SPACING CEDILLA
B9		SUPERSCRIPT DIGIT ONE
BB		RIGHT POINTING GUILLEMET
BC		FRACTION ONE QUARTER
BD		FRACTION ONE HALF
BE		FRACTION THREE QUARTERS
C0		LATIN CAPITAL LETTER A GRAVE
C1		LATIN CAPITAL LETTER A ACUTE
C2		LATIN CAPITAL LETTER A CIRCUMFLEX
C3		LATIN CAPITAL LETTER A TILDE
C4		LATIN CAPITAL LETTER A DIAERESIS
C5		LATIN CAPITAL LETTER A RING
C6		LATIN CAPITAL LETTER A E
C7		LATIN CAPITAL LETTER C CEDILLA
C8		LATIN CAPITAL LETTER E GRAVE
C9		LATIN CAPITAL LETTER E ACUTE
CA		LATIN CAPITAL LETTER E CIRCUMFLEX
CB		LATIN CAPITAL LETTER E DIAERESIS
CC		LATIN CAPITAL LETTER I GRAVE
CD		LATIN CAPITAL LETTER I ACUTE
CE		LATIN CAPITAL LETTER I CIRCUMFLEX
CF		LATIN CAPITAL LETTER I DIAERESIS
D1		LATIN CAPITAL LETTER N TILDE
D2		LATIN CAPITAL LETTER O GRAVE
D3		LATIN CAPITAL LETTER O ACUTE
D4		LATIN CAPITAL LETTER O CIRCUMFLEX
D5		LATIN CAPITAL LETTER O TILDE
D6		LATIN CAPITAL LETTER O DIAERESIS
D8		LATIN CAPITAL LETTER O SLASH
D9		LATIN CAPITAL LETTER U GRAVE
DA		LATIN CAPITAL LETTER U ACUTE
DB		LATIN CAPITAL LETTER U CIRCUMFLEX
DC		LATIN CAPITAL LETTER U DIAERESIS
DD		LATIN CAPITAL LETTER Y ACUTE
E0		LATIN SMALL LETTER A GRAVE
E1		LATIN SMALL LETTER A ACUTE
E2		LATIN SMALL LETTER A CIRCUMFLEX
E3		LATIN SMALL LETTER A TILDE
E4		LATIN SMALL LETTER A DIAERESIS
E5		LATIN SMALL LETTER A RING
E6		LATIN SMALL LETTER A E
E7		LATIN SMALL LETTER C CEDILLA
E8		LATIN SMALL LETTER E GRAVE
E9		LATIN SMALL LETTER E ACUTE
EA		LATIN SMALL LETTER E CIRCUMFLEX
EB		LATIN SMALL LETTER E DIAERESIS
EC		LATIN SMALL LETTER I GRAVE
ED		LATIN SMALL LETTER I ACUTE
EE		LATIN SMALL LETTER I CIRCUMFLEX
EF		LATIN SMALL LETTER I DIAERESIS
F1		LATIN SMALL LETTER N TILDE
F2		LATIN SMALL LETTER O GRAVE
F3		LATIN SMALL LETTER O ACUTE
F4		LATIN SMALL LETTER O CIRCUMFLEX
F5		LATIN SMALL LETTER O TILDE
F6		LATIN SMALL LETTER O DIAERESIS
F8		LATIN SMALL LETTER O SLASH
F9		LATIN SMALL LETTER U GRAVE
FA		LATIN SMALL LETTER U ACUTE
FB		LATIN SMALL LETTER U CIRCUMFLEX
FC		LATIN SMALL LETTER U DIAERESIS
FD		LATIN SMALL LETTER Y ACUTE
FF		LATIN SMALL LETTER Y DIAERESIS
100		LATIN CAPITAL LETTER A MACRON
101		LATIN SMALL LETTER A MACRON
102		LATIN CAPITAL LETTER A BREVE
103		LATIN SMALL LETTER A BREVE
104		LATIN CAPITAL LETTER A OGONEK
105		LATIN SMALL LETTER A OGONEK
106		LATIN CAPITAL LETTER C ACUTE
107		LATIN SMALL LETTER C ACUTE
108		LATIN CAPITAL LETTER C CIRCUMFLEX
109		LATIN SMALL LETTER C CIRCUMFLEX
10A		LATIN CAPITAL LETTER C DOT
10B		LATIN SMALL LETTER C DOT
10C		LATIN CAPITAL LETTER C HACEK
10D		LATIN SMALL LETTER C HACEK
10E		LATIN CAPITAL LETTER D HACEK
10F		LATIN SMALL LETTER D HACEK
110		LATIN CAPITAL LETTER D BAR
111		LATIN SMALL LETTER D BAR
112		LATIN CAPITAL LETTER E MACRON
113		LATIN SMALL LETTER E MACRON
114		LATIN CAPITAL LETTER E BREVE
115		LATIN SMALL LETTER E BREVE
116		LATIN CAPITAL LETTER E DOT
117		LATIN SMALL LETTER E DOT
118		LATIN CAPITAL LETTER E OGONEK
119		LATIN SMALL LETTER E OGONEK
11A		LATIN CAPITAL LETTER E HACEK
11B		LATIN SMALL LETTER E HACEK
11C		LATIN CAPITAL LETTER G CIRCUMFLEX
11D		LATIN SMALL LETTER G CIRCUMFLEX
11E		LATIN CAPITAL LETTER G BREVE
11F		LATIN SMALL LETTER G BREVE
120		LATIN CAPITAL LETTER G DOT
121		LATIN SMALL LETTER G DOT
122		LATIN CAPITAL LETTER G CEDILLA
123		LATIN SMALL LETTER G CEDILLA
124		LATIN CAPITAL LETTER H CIRCUMFLEX
125		LATIN SMALL LETTER H CIRCUMFLEX
126		LATIN CAPITAL LETTER H BAR
127		LATIN SMALL LETTER H BAR
128		LATIN CAPITAL LETTER I TILDE
129		LATIN SMALL LETTER I TILDE
12A		LATIN CAPITAL LETTER I MACRON
12B		LATIN SMALL LETTER I MACRON
12C		LATIN CAPITAL LETTER I BREVE
12D		LATIN SMALL LETTER I BREVE
12E		LATIN CAPITAL LETTER I OGONEK
12F		LATIN SMALL LETTER I OGONEK
130		LATIN CAPITAL LETTER I DOT
132		LATIN CAPITAL LETTER I J
133		LATIN SMALL LETTER I J
134		LATIN CAPITAL LETTER J CIRCUMFLEX
135		LATIN SMALL LETTER J CIRCUMFLEX
136		LATIN CAPITAL LETTER K CEDILLA
137		LATIN SMALL LETTER K CEDILLA
139		LATIN CAPITAL LETTER L ACUTE
13A		LATIN SMALL LETTER L ACUTE
13B		LATIN CAPITAL LETTER L CEDILLA
13C		LATIN SMALL LETTER L CEDILLA
13D		LATIN CAPITAL LETTER L HACEK
13E		LATIN SMALL LETTER L HACEK
141		LATIN CAPITAL LETTER L SLASH
142		LATIN SMALL LETTER L SLASH
143		LATIN CAPITAL LETTER N ACUTE
144		LATIN SMALL LETTER N ACUTE
145		LATIN CAPITAL LETTER N CEDILLA
146		LATIN SMALL LETTER N CEDILLA
147		LATIN CAPITAL LETTER N HACEK
148		LATIN SMALL LETTER N HACEK
149		LATIN SMALL LETTER APOSTROPHE N
14C		LATIN CAPITAL LETTER O MACRON
14D		LATIN SMALL LETTER O MACRON
14E		LATIN CAPITAL LETTER O BREVE
14F		LATIN SMALL LETTER O BREVE
150		LATIN CAPITAL LETTER O DOUBLE ACUTE
151		LATIN SMALL LETTER O DOUBLE ACUTE
152		LATIN CAPITAL LETTER O E
153		LATIN SMALL LETTER O E
154		LATIN CAPITAL LETTER R ACUTE
155		LATIN SMALL LETTER R ACUTE
156		LATIN CAPITAL LETTER R CEDILLA
157		LATIN SMALL LETTER R CEDILLA
158		LATIN CAPITAL LETTER R HACEK
159		LATIN SMALL LETTER R HACEK
15A		LATIN CAPITAL LETTER S ACUTE
15B		LATIN SMALL LETTER S ACUTE
15C		LATIN CAPITAL LETTER S CIRCUMFLEX
15D		LATIN SMALL LETTER S CIRCUMFLEX
15E		LATIN CAPITAL LETTER S CEDILLA
15F		LATIN SMALL LETTER S CEDILLA
160		LATIN CAPITAL LETTER S HACEK
161		LATIN SMALL LETTER S HACEK
162		LATIN CAPITAL LETTER T CEDILLA
163		LATIN SMALL LETTER T CEDILLA
164		LATIN CAPITAL LETTER T HACEK
165		LATIN SMALL LETTER T HACEK
166		LATIN CAPITAL LETTER T BAR
167		LATIN SMALL LETTER T BAR
168		LATIN CAPITAL LETTER U TILDE
169		LATIN SMALL LETTER U TILDE
16A		LATIN CAPITAL LETTER U MACRON
16B		LATIN SMALL LETTER U MACRON
16C		LATIN CAPITAL LETTER U BREVE
16D		LATIN SMALL LETTER U BREVE
16E		LATIN CAPITAL LETTER U RING
16F		LATIN SMALL LETTER U RING
170		LATIN CAPITAL LETTER U DOUBLE ACUTE
171		LATIN SMALL LETTER U DOUBLE ACUTE
172		LATIN CAPITAL LETTER U OGONEK
173		LATIN SMALL LETTER U OGONEK
174		LATIN CAPITAL LETTER W CIRCUMFLEX
175		LATIN SMALL LETTER W CIRCUMFLEX
176		LATIN CAPITAL LETTER Y CIRCUMFLEX
177		LATIN SMALL LETTER Y CIRCUMFLEX
178		LATIN CAPITAL LETTER Y DIAERESIS
179		LATIN CAPITAL LETTER Z ACUTE
17A		LATIN SMALL LETTER Z ACUTE
17B		LATIN CAPITAL LETTER Z DOT
17C		LATIN SMALL LETTER Z DOT
17D		LATIN CAPITAL LETTER Z HACEK
17E		LATIN SMALL LETTER Z HACEK
180		LATIN SMALL LETTER B BAR
181		LATIN CAPITAL LETTER B HOOK
182		LATIN CAPITAL LETTER B TOPBAR
183		LATIN SMALL LETTER B TOPBAR
187		LATIN CAPITAL LETTER C HOOK
188		LATIN SMALL LETTER C HOOK
18A		LATIN CAPITAL LETTER D HOOK
18B		LATIN CAPITAL LETTER D TOPBAR
18C		LATIN SMALL LETTER D TOPBAR
18E		LATIN CAPITAL LETTER TURNED E
190		LATIN CAPITAL LETTER EPSILON
191		LATIN CAPITAL LETTER F HOOK
192		LATIN SMALL LETTER SCRIPT F
193		LATIN CAPITAL LETTER G HOOK
195		LATIN SMALL LETTER H V
197		LATIN CAPITAL LETTER BARRED I
198		LATIN CAPITAL LETTER K HOOK
199		LATIN SMALL LETTER K HOOK
19A		LATIN SMALL LETTER BARRED L
19B		LATIN SMALL LETTER BARRED LAMBDA
19D		LATIN CAPITAL LETTER N HOOK
19F		LATIN CAPITAL LETTER BARRED O
1A0		LATIN CAPITAL LETTER O HORN
1A1		LATIN SMALL LETTER O HORN
1A2		LATIN CAPITAL LETTER O I
1A3		LATIN SMALL LETTER O I
1A4		LATIN CAPITAL LETTER P HOOK
1A5		LATIN SMALL LETTER P HOOK
1A6		LATIN LETTER Y R
1AB		LATIN SMALL LETTER T PALATAL HOOK
1AC		LATIN CAPITAL LETTER T HOOK
1AD		LATIN SMALL LETTER T HOOK
1AE		LATIN CAPITAL LETTER T RETROFLEX HOOK
1AF		LATIN CAPITAL LETTER U HORN
1B0		LATIN SMALL LETTER U HORN
1B2		LATIN CAPITAL LETTER SCRIPT V
1B3		LATIN CAPITAL LETTER Y HOOK
1B4		LATIN SMALL LETTER Y HOOK
1B5		LATIN CAPITAL LETTER Z BAR
1B6		LATIN SMALL LETTER Z BAR
1B7		LATIN CAPITAL LETTER YOGH
1B8		LATIN CAPITAL LETTER REVERSED YOGH
1B9		LATIN SMALL LETTER REVERSED YOGH
1BA		LATIN SMALL LETTER YOGH WITH TAIL
1BB		LATIN LETTER TWO BAR
1BE		LATIN LETTER INVERTED GLOTTAL STOP BAR
1C0		LATIN LETTER PIPE
1C1		LATIN LETTER DOUBLE PIPE
1C2		LATIN LETTER PIPE DOUBLE BAR
1C3		LATIN LETTER EXCLAMATION MARK
1C4		LATIN CAPITAL LETTER D Z HACEK
1C5		LATIN LETTER CAPITAL D SMALL Z HACEK
1C6		LATIN SMALL LETTER D Z HACEK
1C7		LATIN CAPITAL LETTER L J
1C8		LATIN LETTER CAPITAL L SMALL J
1C9		LATIN SMALL LETTER L J
1CA		LATIN CAPITAL LETTER N J
1CB		LATIN LETTER CAPITAL N SMALL J
1CC		LATIN SMALL LETTER N J
1CD		LATIN CAPITAL LETTER A HACEK
1CE		LATIN SMALL LETTER A HACEK
1CF		LATIN CAPITAL LETTER I HACEK
1D0		LATIN SMALL LETTER I HACEK
1D1		LATIN CAPITAL LETTER O HACEK
1D2		LATIN SMALL LETTER O HACEK
1D3		LATIN CAPITAL LETTER U HACEK
1D4		LATIN SMALL LETTER U HACEK
1D5		LATIN CAPITAL LETTER U DIAERESIS MACRON
1D6		LATIN SMALL LETTER U DIAERESIS MACRON
1D7		LATIN CAPITAL LETTER U DIAERESIS ACUTE
1D8		LATIN SMALL LETTER U DIAERESIS ACUTE
1D9		LATIN CAPITAL LETTER U DIAERESIS HACEK
1DA		LATIN SMALL LETTER U DIAERESIS HACEK
1DB		LATIN CAPITAL LETTER U DIAERESIS GRAVE
1DC		LATIN SMALL LETTER U DIAERESIS GRAVE
1DE		LATIN CAPITAL LETTER A DIAERESIS MACRON
1DF		LATIN SMALL LETTER A DIAERESIS MACRON
1E0		LATIN CAPITAL LETTER A DOT MACRON
1E1		LATIN SMALL LETTER A DOT MACRON
1E2		LATIN CAPITAL LETTER A E MACRON
1E3		LATIN SMALL LETTER A E MACRON
1E4		LATIN CAPITAL LETTER G BAR
1E5		LATIN SMALL LETTER G BAR
1E6		LATIN CAPITAL LETTER G HACEK
1E7		LATIN SMALL LETTER G HACEK
1E8		LATIN CAPITAL LETTER K HACEK
1E9		LATIN SMALL LETTER K HACEK
1EA		LATIN CAPITAL LETTER O OGONEK
1EB		LATIN SMALL LETTER O OGONEK
1EC		LATIN CAPITAL LETTER O OGONEK MACRON
1ED		LATIN SMALL LETTER O OGONEK MACRON
1EE		LATIN CAPITAL LETTER YOGH HACEK
1EF		LATIN SMALL LETTER YOGH HACEK
1F0		LATIN SMALL LETTER J HACEK
251		LATIN SMALL LETTER SCRIPT A
252		LATIN SMALL LETTER TURNED SCRIPT A
253		LATIN SMALL LETTER B HOOK
255		LATIN SMALL LETTER C CURL
256		LATIN SMALL LETTER D RETROFLEX HOOK
257		LATIN SMALL LETTER D HOOK
25A		LATIN SMALL LETTER SCHWA HOOK
25B		LATIN SMALL LETTER EPSILON
25C		LATIN SMALL LETTER REVERSED EPSILON
25D		LATIN SMALL LETTER REVERSED EPSILON HOOK
25E		LATIN SMALL LETTER CLOSED REVERSED EPSILON
25F		LATIN SMALL LETTER DOTLESS J BAR
260		LATIN SMALL LETTER G HOOK
264		LATIN SMALL LETTER BABY GAMMA
266		LATIN SMALL LETTER H HOOK
267		LATIN SMALL LETTER HENG HOOK
268		LATIN SMALL LETTER BARRED I
26C		LATIN SMALL LETTER L BELT
26D		LATIN SMALL LETTER L RETROFLEX HOOK
26E		LATIN SMALL LETTER L YOGH
271		LATIN SMALL LETTER M HOOK
272		LATIN SMALL LETTER N HOOK
273		LATIN SMALL LETTER N RETROFLEX HOOK
276		LATIN LETTER SMALL CAPITAL O E
27B		LATIN SMALL LETTER TURNED R HOOK
27D		LATIN SMALL LETTER R HOOK
27E		LATIN SMALL LETTER FISHHOOK R
27F		LATIN SMALL LETTER REVERSED FISHHOOK R
282		LATIN SMALL LETTER S HOOK
284		LATIN SMALL LETTER DOTLESS J BAR HOOK
286		LATIN SMALL LETTER ESH CURL
288		LATIN SMALL LETTER T RETROFLEX HOOK
28B		LATIN SMALL LETTER SCRIPT V
290		LATIN SMALL LETTER Z RETROFLEX HOOK
291		LATIN SMALL LETTER Z CURL
292		LATIN SMALL LETTER YOGH
293		LATIN SMALL LETTER YOGH CURL
295		LATIN LETTER REVERSED GLOTTAL STOP
298		LATIN LETTER BULLSEYE
29A		LATIN SMALL LETTER CLOSED EPSILON
29B		LATIN LETTER SMALL CAPITAL G HOOK
29D		LATIN SMALL LETTER CROSSED-TAIL J
2A0		LATIN SMALL LETTER Q HOOK
2A1		LATIN LETTER GLOTTAL STOP BAR
2A2		LATIN LETTER REVERSED GLOTTAL STOP BAR
2A3		LATIN SMALL LETTER D Z
2A4		LATIN SMALL LETTER D YOGH
2A5		LATIN SMALL LETTER D Z CURL
2A6		LATIN SMALL LETTER T S
2A7		LATIN SMALL LETTER T ESH
2A8		LATIN SMALL LETTER T C CURL
2B1		MODIFIER LETTER SMALL H HOOK
2B5		MODIFIER LETTER SMALL TURNED R HOOK
2C6		MODIFIER LETTER CIRCUMFLEX
2C7		MODIFIER LETTER HACEK
2CA		MODIFIER LETTER ACUTE
2CB		MODIFIER LETTER GRAVE
2CE		MODIFIER LETTER LOW GRAVE
2CF		MODIFIER LETTER LOW ACUTE
2D2		MODIFIER LETTER CENTERED RIGHT HALF RING
2D3		MODIFIER LETTER CENTERED LEFT HALF RING
2D8		SPACING BREVE
2D9		SPACING DOT ABOVE
2DA		SPACING RING ABOVE
2DB		SPACING OGONEK
2DC		SPACING TILDE
2DD		SPACING DOUBLE ACUTE
300		NON-SPACING GRAVE
301		NON-SPACING ACUTE
302		NON-SPACING CIRCUMFLEX
303		NON-SPACING TILDE
304		NON-SPACING MACRON
305		NON-SPACING OVERSCORE
306		NON-SPACING BREVE
307		NON-SPACING DOT ABOVE
308		NON-SPACING DIAERESIS
309		NON-SPACING HOOK ABOVE
30A		NON-SPACING RING ABOVE
30B		NON-SPACING DOUBLE ACUTE
30C		NON-SPACING HACEK
30D		NON-SPACING VERTICAL LINE ABOVE
30E		NON-SPACING DOUBLE VERTICAL LINE ABOVE
30F		NON-SPACING DOUBLE GRAVE
310		NON-SPACING CANDRABINDU
311		NON-SPACING INVERTED BREVE
312		NON-SPACING TURNED COMMA ABOVE
313		NON-SPACING COMMA ABOVE
314		NON-SPACING REVERSED COMMA ABOVE
315		NON-SPACING COMMA ABOVE RIGHT
316		NON-SPACING GRAVE BELOW
317		NON-SPACING ACUTE BELOW
318		NON-SPACING LEFT TACK BELOW
319		NON-SPACING RIGHT TACK BELOW
31A		NON-SPACING LEFT ANGLE ABOVE
31B		NON-SPACING HORN
31C		NON-SPACING LEFT HALF RING BELOW
31D		NON-SPACING UP TACK BELOW
31E		NON-SPACING DOWN TACK BELOW
31F		NON-SPACING PLUS SIGN BELOW
320		NON-SPACING MINUS SIGN BELOW
321		NON-SPACING PALATALIZED HOOK BELOW
322		NON-SPACING RETROFLEX HOOK BELOW
323		NON-SPACING DOT BELOW
324		NON-SPACING DOUBLE DOT BELOW
325		NON-SPACING RING BELOW
326		NON-SPACING COMMA BELOW
327		NON-SPACING CEDILLA
328		NON-SPACING OGONEK
329		NON-SPACING VERTICAL LINE BELOW
32A		NON-SPACING BRIDGE BELOW
32B		NON-SPACING INVERTED DOUBLE ARCH BELOW
32C		NON-SPACING HACEK BELOW
32D		NON-SPACING CIRCUMFLEX BELOW
32E		NON-SPACING BREVE BELOW
32F		NON-SPACING INVERTED BREVE BELOW
330		NON-SPACING TILDE BELOW
331		NON-SPACING MACRON BELOW
332		NON-SPACING UNDERSCORE
333		NON-SPACING DOUBLE UNDERSCORE
334		NON-SPACING TILDE OVERLAY
335		NON-SPACING SHORT BAR OVERLAY
336		NON-SPACING LONG BAR OVERLAY
337		NON-SPACING SHORT SLASH OVERLAY
338		NON-SPACING LONG SLASH OVERLAY
339		NON-SPACING RIGHT HALF RING BELOW
33A		NON-SPACING INVERTED BRIDGE BELOW
33B		NON-SPACING SQUARE BELOW
33C		NON-SPACING SEAGULL BELOW
33D		NON-SPACING X ABOVE
33E		NON-SPACING VERTICAL TILDE
33F		NON-SPACING DOUBLE OVERSCORE
340		NON-SPACING GRAVE TONE MARK
341		NON-SPACING ACUTE TONE MARK
344		GREEK NON-SPACING DIAERESIS TONOS
345		GREEK NON-SPACING IOTA BELOW
374		GREEK UPPER NUMERAL SIGN
37A		GREEK SPACING IOTA BELOW
384		GREEK SPACING TONOS
385		GREEK SPACING DIAERESIS TONOS
386		GREEK CAPITAL LETTER ALPHA TONOS
388		GREEK CAPITAL LETTER EPSILON TONOS
389		GREEK CAPITAL LETTER ETA TONOS
38A		GREEK CAPITAL LETTER IOTA TONOS
38C		GREEK CAPITAL LETTER OMICRON TONOS
38E		GREEK CAPITAL LETTER UPSILON TONOS
38F		GREEK CAPITAL LETTER OMEGA TONOS
390		GREEK SMALL LETTER IOTA DIAERESIS TONOS
39B		GREEK CAPITAL LETTER LAMBDA
3AA		GREEK CAPITAL LETTER IOTA DIAERESIS
3AB		GREEK CAPITAL LETTER UPSILON DIAERESIS
3AC		GREEK SMALL LETTER ALPHA TONOS
3AD		GREEK SMALL LETTER EPSILON TONOS
3AE		GREEK SMALL LETTER ETA TONOS
3AF		GREEK SMALL LETTER IOTA TONOS
3B0		GREEK SMALL LETTER UPSILON DIAERESIS TONOS
3BB		GREEK SMALL LETTER LAMBDA
3CA		GREEK SMALL LETTER IOTA DIAERESIS
3CB		GREEK SMALL LETTER UPSILON DIAERESIS
3CC		GREEK SMALL LETTER OMICRON TONOS
3CD		GREEK SMALL LETTER UPSILON TONOS
3CE		GREEK SMALL LETTER OMEGA TONOS
3D0		GREEK SMALL LETTER CURLED BETA
3D1		GREEK SMALL LETTER SCRIPT THETA
3D2		GREEK CAPITAL LETTER UPSILON HOOK
3D3		GREEK CAPITAL LETTER UPSILON HOOK TONOS
3D4		GREEK CAPITAL LETTER UPSILON HOOK DIAERESIS
3D5		GREEK SMALL LETTER SCRIPT PHI
3D6		GREEK SMALL LETTER OMEGA PI
3DA		GREEK CAPITAL LETTER STIGMA
3DC		GREEK CAPITAL LETTER DIGAMMA
3DE		GREEK CAPITAL LETTER KOPPA
3E0		GREEK CAPITAL LETTER SAMPI
3E2		GREEK CAPITAL LETTER SHEI
3E3		GREEK SMALL LETTER SHEI
3E4		GREEK CAPITAL LETTER FEI
3E5		GREEK SMALL LETTER FEI
3E6		GREEK CAPITAL LETTER KHEI
3E7		GREEK SMALL LETTER KHEI
3E8		GREEK CAPITAL LETTER HORI
3E9		GREEK SMALL LETTER HORI
3EA		GREEK CAPITAL LETTER GANGIA
3EB		GREEK SMALL LETTER GANGIA
3EC		GREEK CAPITAL LETTER SHIMA
3ED		GREEK SMALL LETTER SHIMA
3EE		GREEK CAPITAL LETTER DEI
3EF		GREEK SMALL LETTER DEI
3F0		GREEK SMALL LETTER SCRIPT KAPPA
3F1		GREEK SMALL LETTER TAILED RHO
3F2		GREEK SMALL LETTER LUNATE SIGMA
404		CYRILLIC CAPITAL LETTER E
406		CYRILLIC CAPITAL LETTER I
413		CYRILLIC CAPITAL LETTER GE
418		CYRILLIC CAPITAL LETTER II
419		CYRILLIC CAPITAL LETTER SHORT II
425		CYRILLIC CAPITAL LETTER KHA
42B		CYRILLIC CAPITAL LETTER YERI
42D		CYRILLIC CAPITAL LETTER REVERSED E
42E		CYRILLIC CAPITAL LETTER IU
42F		CYRILLIC CAPITAL LETTER IA
433		CYRILLIC SMALL LETTER GE
438		CYRILLIC SMALL LETTER II
439		CYRILLIC SMALL LETTER SHORT II
445		CYRILLIC SMALL LETTER KHA
44B		CYRILLIC SMALL LETTER YERI
44D		CYRILLIC SMALL LETTER REVERSED E
44E		CYRILLIC SMALL LETTER IU
44F		CYRILLIC SMALL LETTER IA
454		CYRILLIC SMALL LETTER E
456		CYRILLIC SMALL LETTER I
476		CYRILLIC CAPITAL LETTER IZHITSA DOUBLE GRAVE
477		CYRILLIC SMALL LETTER IZHITSA DOUBLE GRAVE
478		CYRILLIC CAPITAL LETTER UK DIGRAPH
479		CYRILLIC SMALL LETTER UK DIGRAPH
47C		CYRILLIC CAPITAL LETTER OMEGA TITLO
47D		CYRILLIC SMALL LETTER OMEGA TITLO
483		CYRILLIC NON-SPACING TITLO
484		CYRILLIC NON-SPACING PALATALIZATION
485		CYRILLIC NON-SPACING DASIA PNEUMATA
486		CYRILLIC NON-SPACING PSILI PNEUMATA
490		CYRILLIC CAPITAL LETTER GE WITH UPTURN
491		CYRILLIC SMALL LETTER GE WITH UPTURN
492		CYRILLIC CAPITAL LETTER GE BAR
493		CYRILLIC SMALL LETTER GE BAR
494		CYRILLIC CAPITAL LETTER GE HOOK
495		CYRILLIC SMALL LETTER GE HOOK
496		CYRILLIC CAPITAL LETTER ZHE WITH RIGHT DESCENDER
497		CYRILLIC SMALL LETTER ZHE WITH RIGHT DESCENDER
498		CYRILLIC CAPITAL LETTER ZE CEDILLA
499		CYRILLIC SMALL LETTER ZE CEDILLA
49A		CYRILLIC CAPITAL LETTER KA WITH RIGHT DESCENDER
49B		CYRILLIC SMALL LETTER KA WITH RIGHT DESCENDER
49C		CYRILLIC CAPITAL LETTER KA VERTICAL BAR
49D		CYRILLIC SMALL LETTER KA VERTICAL BAR
49E		CYRILLIC CAPITAL LETTER KA BAR
49F		CYRILLIC SMALL LETTER KA BAR
4A0		CYRILLIC CAPITAL LETTER REVERSED GE KA
4A1		CYRILLIC SMALL LETTER REVERSED GE KA
4A2		CYRILLIC CAPITAL LETTER EN WITH RIGHT DESCENDER
4A3		CYRILLIC SMALL LETTER EN WITH RIGHT DESCENDER
4A4		CYRILLIC CAPITAL LETTER EN GE
4A5		CYRILLIC SMALL LETTER EN GE
4A6		CYRILLIC CAPITAL LETTER PE HOOK
4A7		CYRILLIC SMALL LETTER PE HOOK
4A8		CYRILLIC CAPITAL LETTER O HOOK
4A9		CYRILLIC SMALL LETTER O HOOK
4AA		CYRILLIC CAPITAL LETTER ES CEDILLA
4AB		CYRILLIC SMALL LETTER ES CEDILLA
4AC		CYRILLIC CAPITAL LETTER TE WITH RIGHT DESCENDER
4AD		CYRILLIC SMALL LETTER TE WITH RIGHT DESCENDER
4B0		CYRILLIC CAPITAL LETTER STRAIGHT U BAR
4B1		CYRILLIC SMALL LETTER STRAIGHT U BAR
4B2		CYRILLIC CAPITAL LETTER KHA WITH RIGHT DESCENDER
4B3		CYRILLIC SMALL LETTER KHA WITH RIGHT DESCENDER
4B4		CYRILLIC CAPITAL LETTER TE TSE
4B5		CYRILLIC SMALL LETTER TE TSE
4B6		CYRILLIC CAPITAL LETTER CHE WITH RIGHT DESCENDER
4B7		CYRILLIC SMALL LETTER CHE WITH RIGHT DESCENDER
4B8		CYRILLIC CAPITAL LETTER CHE VERTICAL BAR
4B9		CYRILLIC SMALL LETTER CHE VERTICAL BAR
4BA		CYRILLIC CAPITAL LETTER H
4BB		CYRILLIC SMALL LETTER H
4BC		CYRILLIC CAPITAL LETTER IE HOOK
4BD		CYRILLIC SMALL LETTER IE HOOK
4BE		CYRILLIC CAPITAL LETTER IE HOOK OGONEK
4BF		CYRILLIC SMALL LETTER IE HOOK OGONEK
4C0		CYRILLIC LETTER I
4C1		CYRILLIC CAPITAL LETTER SHORT ZHE
4C2		CYRILLIC SMALL LETTER SHORT ZHE
4C3		CYRILLIC CAPITAL LETTER KA HOOK
4C4		CYRILLIC SMALL LETTER KA HOOK
4C7		CYRILLIC CAPITAL LETTER EN HOOK
4C8		CYRILLIC SMALL LETTER EN HOOK
4CB		CYRILLIC CAPITAL LETTER CHE WITH LEFT DESCENDER
4CC		CYRILLIC SMALL LETTER CHE WITH LEFT DESCENDER
542		ARMENIAN CAPITAL LETTER LAD
55A		ARMENIAN MODIFIER LETTER RIGHT HALF RING
572		ARMENIAN SMALL LETTER LAD
589		ARMENIAN PERIOD
5BC		HEBREW POINT DAGESH
5C0		HEBREW POINT PASEQ
5F0		HEBREW LETTER DOUBLE VAV
5F1		HEBREW LETTER VAV YOD
5F2		HEBREW LETTER DOUBLE YOD
621		ARABIC LETTER HAMZAH
622		ARABIC LETTER MADDAH ON ALEF
623		ARABIC LETTER HAMZAH ON ALEF
624		ARABIC LETTER HAMZAH ON WAW
625		ARABIC LETTER HAMZAH UNDER ALEF
626		ARABIC LETTER HAMZAH ON YA
628		ARABIC LETTER BAA
629		ARABIC LETTER TAA MARBUTAH
62A		ARABIC LETTER TAA
62B		ARABIC LETTER THAA
62D		ARABIC LETTER HAA
62E		ARABIC LETTER KHAA
631		ARABIC LETTER RA
638		ARABIC LETTER DHAH
641		ARABIC LETTER FA
643		ARABIC LETTER CAF
647		ARABIC LETTER HA
649		ARABIC LETTER ALEF MAQSURAH
64A		ARABIC LETTER YA
64E		ARABIC FATHAH
64F		ARABIC DAMMAH
650		ARABIC KASRAH
651		ARABIC SHADDAH
670		ARABIC ALEF ABOVE
671		ARABIC LETTER HAMZAT WASL ON ALEF
672		ARABIC LETTER WAVY HAMZAH ON ALEF
673		ARABIC LETTER WAVY HAMZAH UNDER ALEF
674		ARABIC LETTER HIGH HAMZAH
675		ARABIC LETTER HIGH HAMZAH ALEF
676		ARABIC LETTER HIGH HAMZAH WAW
677		ARABIC LETTER HIGH HAMZAH WAW WITH DAMMAH
678		ARABIC LETTER HIGH HAMZAH YA
679		ARABIC LETTER TAA WITH SMALL TAH
67A		ARABIC LETTER TAA WITH TWO DOTS VERTICAL ABOVE
67B		ARABIC LETTER BAA WITH TWO DOTS VERTICAL BELOW
67C		ARABIC LETTER TAA WITH RING
67D		ARABIC LETTER TAA WITH THREE DOTS ABOVE DOWNWARD
67E		ARABIC LETTER TAA WITH THREE DOTS BELOW
67F		ARABIC LETTER TAA WITH FOUR DOTS ABOVE
680		ARABIC LETTER BAA WITH FOUR DOTS BELOW
681		ARABIC LETTER HAMZAH ON HAA
682		ARABIC LETTER HAA WITH TWO DOTS VERTICAL ABOVE
683		ARABIC LETTER HAA WITH MIDDLE TWO DOTS
684		ARABIC LETTER HAA WITH MIDDLE TWO DOTS VERTICAL
685		ARABIC LETTER HAA WITH THREE DOTS ABOVE
686		ARABIC LETTER HAA WITH MIDDLE THREE DOTS DOWNWARD
687		ARABIC LETTER HAA WITH MIDDLE FOUR DOTS
688		ARABIC LETTER DAL WITH SMALL TAH
68C		ARABIC LETTER DAL WITH TWO DOTS ABOVE
68D		ARABIC LETTER DAL WITH TWO DOTS BELOW
68E		ARABIC LETTER DAL WITH THREE DOTS ABOVE
68F		ARABIC LETTER DAL WITH THREE DOTS ABOVE DOWNWARD
691		ARABIC LETTER RA WITH SMALL TAH
692		ARABIC LETTER RA WITH SMALL V
693		ARABIC LETTER RA WITH RING
694		ARABIC LETTER RA WITH DOT BELOW
695		ARABIC LETTER RA WITH SMALL V BELOW
696		ARABIC LETTER RA WITH DOT BELOW AND DOT ABOVE
697		ARABIC LETTER RA WITH TWO DOTS ABOVE
698		ARABIC LETTER RA WITH THREE DOTS ABOVE
699		ARABIC LETTER RA WITH FOUR DOTS ABOVE
6A1		ARABIC LETTER DOTLESS FA
6A2		ARABIC LETTER FA WITH DOT MOVED BELOW
6A3		ARABIC LETTER FA WITH DOT BELOW
6A4		ARABIC LETTER FA WITH THREE DOTS ABOVE
6A5		ARABIC LETTER FA WITH THREE DOTS BELOW
6A6		ARABIC LETTER FA WITH FOUR DOTS ABOVE
6A9		ARABIC LETTER OPEN CAF
6AA		ARABIC LETTER SWASH CAF
6AB		ARABIC LETTER CAF WITH RING
6AC		ARABIC LETTER CAF WITH DOT ABOVE
6AD		ARABIC LETTER CAF WITH THREE DOTS ABOVE
6AE		ARABIC LETTER CAF WITH THREE DOTS BELOW
6B1		ARABIC LETTER GAF WITH TWO DOTS ABOVE
6B3		ARABIC LETTER GAF WITH TWO DOTS VERTICAL BELOW
6BA		ARABIC LETTER DOTLESS NOON
6BB		ARABIC LETTER DOTLESS NOON WITH SMALL TAH
6BE		ARABIC LETTER KNOTTED HA
6C0		ARABIC LETTER HAMZAH ON HA
6C1		ARABIC LETTER HA GOAL
6C2		ARABIC LETTER HAMZAH ON HA GOAL
6C3		ARABIC LETTER TAA MARBUTAH GOAL
6C5		ARABIC LETTER WAW WITH BAR
6C6		ARABIC LETTER WAW WITH SMALL V
6C7		ARABIC LETTER WAW WITH DAMMAH
6C8		ARABIC LETTER WAW WITH ALEF ABOVE
6C9		ARABIC LETTER WAW WITH INVERTED SMALL V
6CB		ARABIC LETTER WAW WITH THREE DOTS ABOVE
6CC		ARABIC LETTER DOTLESS YA
6CD		ARABIC LETTER YA WITH TAIL
6CE		ARABIC LETTER YA WITH SMALL V
6D0		ARABIC LETTER YA WITH TWO DOTS VERTICAL BELOW
6D1		ARABIC LETTER YA WITH THREE DOTS BELOW
6D2		ARABIC LETTER YA BARREE
6D3		ARABIC LETTER HAMZAH ON YA BARREE
6D4		ARABIC PERIOD
6F0		EASTERN ARABIC-INDIC DIGIT ZERO
6F1		EASTERN ARABIC-INDIC DIGIT ONE
6F2		EASTERN ARABIC-INDIC DIGIT TWO
6F3		EASTERN ARABIC-INDIC DIGIT THREE
6F4		EASTERN ARABIC-INDIC DIGIT FOUR
6F5		EASTERN ARABIC-INDIC DIGIT FIVE
6F6		EASTERN ARABIC-INDIC DIGIT SIX
6F7		EASTERN ARABIC-INDIC DIGIT SEVEN
6F8		EASTERN ARABIC-INDIC DIGIT EIGHT
6F9		EASTERN ARABIC-INDIC DIGIT NINE
9F1		BENGALI LETTER VA WITH LOWER DIAGONAL
E01		THAI LETTER KO KAI
E02		THAI LETTER KHO KHAI
E03		THAI LETTER KHO KHUAT
E04		THAI LETTER KHO KHWAI
E05		THAI LETTER KHO KHON
E06		THAI LETTER KHO RAKHANG
E07		THAI LETTER NGO NGU
E08		THAI LETTER CHO CHAN
E09		THAI LETTER CHO CHING
E0A		THAI LETTER CHO CHANG
E0B		THAI LETTER SO SO
E0C		THAI LETTER CHO CHOE
E0D		THAI LETTER YO YING
E0E		THAI LETTER DO CHADA
E0F		THAI LETTER TO PATAK
E10		THAI LETTER THO THAN
E11		THAI LETTER THO NANGMONTHO
E12		THAI LETTER THO PHUTHAO
E13		THAI LETTER NO NEN
E14		THAI LETTER DO DEK
E15		THAI LETTER TO TAO
E16		THAI LETTER THO THUNG
E17		THAI LETTER THO THAHAN
E18		THAI LETTER THO THONG
E19		THAI LETTER NO NU
E1A		THAI LETTER BO BAIMAI
E1B		THAI LETTER PO PLA
E1C		THAI LETTER PHO PHUNG
E1D		THAI LETTER FO FA
E1E		THAI LETTER PHO PHAN
E1F		THAI LETTER FO FAN
E20		THAI LETTER PHO SAMPHAO
E21		THAI LETTER MO MA
E22		THAI LETTER YO YAK
E23		THAI LETTER RO RUA
E24		THAI LETTER RU
E25		THAI LETTER LO LING
E26		THAI LETTER LU
E27		THAI LETTER WO WAEN
E28		THAI LETTER SO SALA
E29		THAI LETTER SO RUSI
E2A		THAI LETTER SO SUA
E2B		THAI LETTER HO HIP
E2C		THAI LETTER LO CHULA
E2D		THAI LETTER O ANG
E2E		THAI LETTER HO NOK HUK
E2F		THAI PAI YAN NOI
E30		THAI VOWEL SIGN SARA A
E31		THAI VOWEL SIGN MAI HAN-AKAT
E32		THAI VOWEL SIGN SARA AA
E33		THAI VOWEL SIGN SARA AM
E34		THAI VOWEL SIGN SARA I
E35		THAI VOWEL SIGN SARA II
E36		THAI VOWEL SIGN SARA UE
E37		THAI VOWEL SIGN SARA UEE
E38		THAI VOWEL SIGN SARA U
E39		THAI VOWEL SIGN SARA UU
E3A		THAI VOWEL SIGN PHINTHU
E3F		THAI BAHT SIGN
E40		THAI VOWEL SIGN SARA E
E41		THAI VOWEL SIGN SARA AE
E42		THAI VOWEL SIGN SARA O
E43		THAI VOWEL SIGN SARA MAI MUAN
E44		THAI VOWEL SIGN SARA MAI MALAI
E45		THAI LAK KHANG YAO
E46		THAI MAI YAMOK
E47		THAI VOWEL SIGN MAI TAI KHU
E48		THAI TONE MAI EK
E49		THAI TONE MAI THO
E4A		THAI TONE MAI TRI
E4B		THAI TONE MAI CHATTAWA
E4C		THAI THANTHAKHAT
E4D		THAI NIKKHAHIT
E4E		THAI YAMAKKAN
E4F		THAI FONGMAN
E5A		THAI ANGKHANKHU
E5B		THAI KHOMUT
F04		TIBETAN SINGLE ORNAMENT
F08		TIBETAN RGYANSHAD
F0B		TIBETAN TSEG
F0D		TIBETAN SHAD
F0E		TIBETAN DOUBLE SHAD
F11		TIBETAN RINCHANPHUNGSHAD
F14		TIBETAN COMMA
F35		TIBETAN HONORIFIC UNDER RING
F37		TIBETAN UNDER RING
F39		TIBETAN LENITION MARK
F3C		TIBETAN LEFT BRACE
F3D		TIBETAN RIGHT BRACE
F4A		TIBETAN LETTER REVERSED TA
F4B		TIBETAN LETTER REVERSED THA
F4C		TIBETAN LETTER REVERSED DA
F4E		TIBETAN LETTER REVERSED NA
F60		TIBETAN LETTER AA
F65		TIBETAN LETTER REVERSED SHA
F7B		TIBETAN VOWEL SIGN AI
F7D		TIBETAN VOWEL SIGN AU
F7E		TIBETAN ANUSVARA
F7F		TIBETAN VISARGA
F80		TIBETAN VOWEL SIGN SHORT I
F82		TIBETAN CANDRABINDU WITH ORNAMENT
F83		TIBETAN CANDRABINDU
F84		TIBETAN VIRAMA
F85		TIBETAN CHUCHENYIGE
10D0		GEORGIAN SMALL LETTER AN
10D1		GEORGIAN SMALL LETTER BAN
10D2		GEORGIAN SMALL LETTER GAN
10D3		GEORGIAN SMALL LETTER DON
10D4		GEORGIAN SMALL LETTER EN
10D5		GEORGIAN SMALL LETTER VIN
10D6		GEORGIAN SMALL LETTER ZEN
10D7		GEORGIAN SMALL LETTER TAN
10D8		GEORGIAN SMALL LETTER IN
10D9		GEORGIAN SMALL LETTER KAN
10DA		GEORGIAN SMALL LETTER LAS
10DB		GEORGIAN SMALL LETTER MAN
10DC		GEORGIAN SMALL LETTER NAR
10DD		GEORGIAN SMALL LETTER ON
10DE		GEORGIAN SMALL LETTER PAR
10DF		GEORGIAN SMALL LETTER ZHAR
10E0		GEORGIAN SMALL LETTER RAE
10E1		GEORGIAN SMALL LETTER SAN
10E2		GEORGIAN SMALL LETTER TAR
10E3		GEORGIAN SMALL LETTER UN
10E4		GEORGIAN SMALL LETTER PHAR
10E5		GEORGIAN SMALL LETTER KHAR
10E6		GEORGIAN SMALL LETTER GHAN
10E7		GEORGIAN SMALL LETTER QAR
10E8		GEORGIAN SMALL LETTER SHIN
10E9		GEORGIAN SMALL LETTER CHIN
10EA		GEORGIAN SMALL LETTER CAN
10EB		GEORGIAN SMALL LETTER JIL
10EC		GEORGIAN SMALL LETTER CIL
10ED		GEORGIAN SMALL LETTER CHAR
10EE		GEORGIAN SMALL LETTER XAN
10EF		GEORGIAN SMALL LETTER JHAN
10F0		GEORGIAN SMALL LETTER HAE
10F1		GEORGIAN SMALL LETTER HE
10F2		GEORGIAN SMALL LETTER HIE
10F3		GEORGIAN SMALL LETTER WE
10F4		GEORGIAN SMALL LETTER HAR
10F5		GEORGIAN SMALL LETTER HOE
10F6		GEORGIAN SMALL LETTER FI
2015		QUOTATION DASH
2016		DOUBLE VERTICAL BAR
2017		SPACING DOUBLE UNDERSCORE
2018		SINGLE TURNED COMMA QUOTATION MARK
2019		SINGLE COMMA QUOTATION MARK
201A		LOW SINGLE COMMA QUOTATION MARK
201B		SINGLE REVERSED COMMA QUOTATION MARK
201C		DOUBLE TURNED COMMA QUOTATION MARK
201D		DOUBLE COMMA QUOTATION MARK
201E		LOW DOUBLE COMMA QUOTATION MARK
201F		DOUBLE REVERSED COMMA QUOTATION MARK
2039		LEFT POINTING SINGLE GUILLEMET
203A		RIGHT POINTING SINGLE GUILLEMET
203E		SPACING OVERSCORE
2070		SUPERSCRIPT DIGIT ZERO
2074		SUPERSCRIPT DIGIT FOUR
2075		SUPERSCRIPT DIGIT FIVE
2076		SUPERSCRIPT DIGIT SIX
2077		SUPERSCRIPT DIGIT SEVEN
2078		SUPERSCRIPT DIGIT EIGHT
2079		SUPERSCRIPT DIGIT NINE
207B		SUPERSCRIPT HYPHEN-MINUS
207D		SUPERSCRIPT OPENING PARENTHESIS
207E		SUPERSCRIPT CLOSING PARENTHESIS
2080		SUBSCRIPT DIGIT ZERO
2081		SUBSCRIPT DIGIT ONE
2082		SUBSCRIPT DIGIT TWO
2083		SUBSCRIPT DIGIT THREE
2084		SUBSCRIPT DIGIT FOUR
2085		SUBSCRIPT DIGIT FIVE
2086		SUBSCRIPT DIGIT SIX
2087		SUBSCRIPT DIGIT SEVEN
2088		SUBSCRIPT DIGIT EIGHT
2089		SUBSCRIPT DIGIT NINE
208B		SUBSCRIPT HYPHEN-MINUS
208D		SUBSCRIPT OPENING PARENTHESIS
208E		SUBSCRIPT CLOSING PARENTHESIS
20D0		NON-SPACING LEFT HARPOON ABOVE
20D1		NON-SPACING RIGHT HARPOON ABOVE
20D2		NON-SPACING LONG VERTICAL BAR OVERLAY
20D3		NON-SPACING SHORT VERTICAL BAR OVERLAY
20D4		NON-SPACING ANTICLOCKWISE ARROW ABOVE
20D5		NON-SPACING CLOCKWISE ARROW ABOVE
20D6		NON-SPACING LEFT ARROW ABOVE
20D7		NON-SPACING RIGHT ARROW ABOVE
20D8		NON-SPACING RING OVERLAY
20D9		NON-SPACING CLOCKWISE RING OVERLAY
20DA		NON-SPACING ANTICLOCKWISE RING OVERLAY
20DB		NON-SPACING THREE DOTS ABOVE
20DC		NON-SPACING FOUR DOTS ABOVE
20DD		ENCLOSING CIRCLE
20DE		ENCLOSING SQUARE
20DF		ENCLOSING DIAMOND
20E0		ENCLOSING CIRCLE SLASH
20E1		NON-SPACING LEFT RIGHT ARROW ABOVE
2102		DOUBLE-STRUCK C
2103		DEGREES CENTIGRADE
2104		C L SYMBOL
2107		EULERS
2109		DEGREES FAHRENHEIT
210B		SCRIPT H
210C		BLACK-LETTER H
210D		DOUBLE-STRUCK H
210F		PLANCK CONSTANT OVER 2 PI
2110		SCRIPT I
2111		BLACK-LETTER I
2112		SCRIPT L
2115		DOUBLE-STRUCK N
2116		NUMERO
2118		SCRIPT P
2119		DOUBLE-STRUCK P
211A		DOUBLE-STRUCK Q
211B		SCRIPT R
211C		BLACK-LETTER R
211D		DOUBLE-STRUCK R
2121		T E L SYMBOL
2122		TRADEMARK
2124		DOUBLE-STRUCK Z
2125		OUNCE
2126		OHM
2127		MHO
2128		BLACK-LETTER Z
212A		DEGREES KELVIN
212B		ANGSTROM UNIT
212C		SCRIPT B
212D		BLACK-LETTER C
2130		SCRIPT E
2131		SCRIPT F
2132		TURNED F
2133		SCRIPT M
2135		FIRST TRANSFINITE CARDINAL
2136		SECOND TRANSFINITE CARDINAL
2137		THIRD TRANSFINITE CARDINAL
2138		FOURTH TRANSFINITE CARDINAL
2153		FRACTION ONE THIRD
2154		FRACTION TWO THIRDS
2155		FRACTION ONE FIFTH
2156		FRACTION TWO FIFTHS
2157		FRACTION THREE FIFTHS
2158		FRACTION FOUR FIFTHS
2159		FRACTION ONE SIXTH
215A		FRACTION FIVE SIXTHS
215B		FRACTION ONE EIGHTH
215C		FRACTION THREE EIGHTHS
215D		FRACTION FIVE EIGHTHS
215E		FRACTION SEVEN EIGHTHS
2190		LEFT ARROW
2191		UP ARROW
2192		RIGHT ARROW
2193		DOWN ARROW
2196		UPPER LEFT ARROW
2197		UPPER RIGHT ARROW
2198		LOWER RIGHT ARROW
2199		LOWER LEFT ARROW
219A		LEFT ARROW WITH STROKE
219B		RIGHT ARROW WITH STROKE
219C		LEFT WAVE ARROW
219D		RIGHT WAVE ARROW
219E		LEFT TWO HEADED ARROW
219F		UP TWO HEADED ARROW
21A0		RIGHT TWO HEADED ARROW
21A1		DOWN TWO HEADED ARROW
21A2		LEFT ARROW WITH TAIL
21A3		RIGHT ARROW WITH TAIL
21A4		LEFT ARROW FROM BAR
21A5		UP ARROW FROM BAR
21A6		RIGHT ARROW FROM BAR
21A7		DOWN ARROW FROM BAR
21A9		LEFT ARROW WITH HOOK
21AA		RIGHT ARROW WITH HOOK
21AB		LEFT ARROW WITH LOOP
21AC		RIGHT ARROW WITH LOOP
21AF		DOWN ZIGZAG ARROW
21B0		UP ARROW WITH TIP LEFT
21B1		UP ARROW WITH TIP RIGHT
21B2		DOWN ARROW WITH TIP LEFT
21B3		DOWN ARROW WITH TIP RIGHT
21B4		RIGHT ARROW WITH CORNER DOWN
21B5		DOWN ARROW WITH CORNER LEFT
21B8		UPPER LEFT ARROW TO LONG BAR
21B9		LEFT ARROW TO BAR OVER RIGHT ARROW TO BAR
21BC		LEFT HARPOON WITH BARB UP
21BD		LEFT HARPOON WITH BARB DOWN
21BE		UP HARPOON WITH BARB RIGHT
21BF		UP HARPOON WITH BARB LEFT
21C0		RIGHT HARPOON WITH BARB UP
21C1		RIGHT HARPOON WITH BARB DOWN
21C2		DOWN HARPOON WITH BARB RIGHT
21C3		DOWN HARPOON WITH BARB LEFT
21C4		RIGHT ARROW OVER LEFT ARROW
21C5		UP ARROW LEFT OF DOWN ARROW
21C6		LEFT ARROW OVER RIGHT ARROW
21C7		LEFT PAIRED ARROWS
21C8		UP PAIRED ARROWS
21C9		RIGHT PAIRED ARROWS
21CA		DOWN PAIRED ARROWS
21CB		LEFT HARPOON OVER RIGHT HARPOON
21CC		RIGHT HARPOON OVER LEFT HARPOON
21CD		LEFT DOUBLE ARROW WITH STROKE
21CF		RIGHT DOUBLE ARROW WITH STROKE
21D0		LEFT DOUBLE ARROW
21D1		UP DOUBLE ARROW
21D2		RIGHT DOUBLE ARROW
21D3		DOWN DOUBLE ARROW
21D6		UPPER LEFT DOUBLE ARROW
21D7		UPPER RIGHT DOUBLE ARROW
21D8		LOWER RIGHT DOUBLE ARROW
21D9		LOWER LEFT DOUBLE ARROW
21DA		LEFT TRIPLE ARROW
21DB		RIGHT TRIPLE ARROW
21DC		LEFT SQUIGGLE ARROW
21DD		RIGHT SQUIGGLE ARROW
21DE		UP ARROW WITH DOUBLE STROKE
21DF		DOWN ARROW WITH DOUBLE STROKE
21E0		LEFT DASHED ARROW
21E1		UP DASHED ARROW
21E2		RIGHT DASHED ARROW
21E3		DOWN DASHED ARROW
21E4		LEFT ARROW TO BAR
21E5		RIGHT ARROW TO BAR
21E6		WHITE LEFT ARROW
21E7		WHITE UP ARROW
21E8		WHITE RIGHT ARROW
21E9		WHITE DOWN ARROW
21EA		WHITE UP ARROW FROM BAR
2254		COLON EQUAL
2255		EQUAL COLON
2264		LESS THAN OR EQUAL TO
2265		GREATER THAN OR EQUAL TO
2266		LESS THAN OVER EQUAL TO
2267		GREATER THAN OVER EQUAL TO
2268		LESS THAN BUT NOT EQUAL TO
2269		GREATER THAN BUT NOT EQUAL TO
226A		MUCH LESS THAN
226B		MUCH GREATER THAN
226E		NOT LESS THAN
226F		NOT GREATER THAN
2270		NEITHER LESS THAN NOR EQUAL TO
2271		NEITHER GREATER THAN NOR EQUAL TO
2272		LESS THAN OR EQUIVALENT TO
2273		GREATER THAN OR EQUIVALENT TO
2274		NEITHER LESS THAN NOR EQUIVALENT TO
2275		NEITHER GREATER THAN NOR EQUIVALENT TO
2276		LESS THAN OR GREATER THAN
2277		GREATER THAN OR LESS THAN
2278		NEITHER LESS THAN NOR GREATER THAN
2279		NEITHER GREATER THAN NOR LESS THAN
228A		SUBSET OF OR NOT EQUAL TO
228B		SUPERSET OF OR NOT EQUAL TO
22D6		LESS THAN WITH DOT
22D7		GREATER THAN WITH DOT
22D8		VERY MUCH LESS THAN
22D9		VERY MUCH GREATER THAN
22DA		LESS THAN EQUAL TO OR GREATER THAN
22DB		GREATER THAN EQUAL TO OR LESS THAN
22DC		EQUAL TO OR LESS THAN
22DD		EQUAL TO OR GREATER THAN
22E6		LESS THAN BUT NOT EQUIVALENT TO
22E7		GREATER THAN BUT NOT EQUIVALENT TO
2318		COMMAND KEY
2324		ENTER KEY
2326		DELETE TO THE RIGHT KEY
2327		CLEAR KEY
2329		BRA
232A		KET
232B		DELETE TO THE LEFT KEY
2400		GRAPHIC FOR NULL
2401		GRAPHIC FOR START OF HEADING
2402		GRAPHIC FOR START OF TEXT
2403		GRAPHIC FOR END OF TEXT
2404		GRAPHIC FOR END OF TRANSMISSION
2405		GRAPHIC FOR ENQUIRY
2406		GRAPHIC FOR ACKNOWLEDGE
2407		GRAPHIC FOR BELL
2408		GRAPHIC FOR BACKSPACE
2409		GRAPHIC FOR HORIZONTAL TABULATION
240A		GRAPHIC FOR LINE FEED
240B		GRAPHIC FOR VERTICAL TABULATION
240C		GRAPHIC FOR FORM FEED
240D		GRAPHIC FOR CARRIAGE RETURN
240E		GRAPHIC FOR SHIFT OUT
240F		GRAPHIC FOR SHIFT IN
2410		GRAPHIC FOR DATA LINK ESCAPE
2411		GRAPHIC FOR DEVICE CONTROL ONE
2412		GRAPHIC FOR DEVICE CONTROL TWO
2413		GRAPHIC FOR DEVICE CONTROL THREE
2414		GRAPHIC FOR DEVICE CONTROL FOUR
2415		GRAPHIC FOR NEGATIVE ACKNOWLEDGE
2416		GRAPHIC FOR SYNCHRONOUS IDLE
2417		GRAPHIC FOR END OF TRANSMISSION BLOCK
2418		GRAPHIC FOR CANCEL
2419		GRAPHIC FOR END OF MEDIUM
241A		GRAPHIC FOR SUBSTITUTE
241B		GRAPHIC FOR ESCAPE
241C		GRAPHIC FOR FILE SEPARATOR
241D		GRAPHIC FOR GROUP SEPARATOR
241E		GRAPHIC FOR RECORD SEPARATOR
241F		GRAPHIC FOR UNIT SEPARATOR
2420		GRAPHIC FOR SPACE
2421		GRAPHIC FOR DELETE
2422		BLANK
2424		GRAPHIC FOR NEWLINE
2488		DIGIT ONE PERIOD
2489		DIGIT TWO PERIOD
248A		DIGIT THREE PERIOD
248B		DIGIT FOUR PERIOD
248C		DIGIT FIVE PERIOD
248D		DIGIT SIX PERIOD
248E		DIGIT SEVEN PERIOD
248F		DIGIT EIGHT PERIOD
2490		DIGIT NINE PERIOD
2491		NUMBER TEN PERIOD
2492		NUMBER ELEVEN PERIOD
2493		NUMBER TWELVE PERIOD
2494		NUMBER THIRTEEN PERIOD
2495		NUMBER FOURTEEN PERIOD
2496		NUMBER FIFTEEN PERIOD
2497		NUMBER SIXTEEN PERIOD
2498		NUMBER SEVENTEEN PERIOD
2499		NUMBER EIGHTEEN PERIOD
249A		NUMBER NINETEEN PERIOD
249B		NUMBER TWENTY PERIOD
2500		FORMS LIGHT HORIZONTAL
2501		FORMS HEAVY HORIZONTAL
2502		FORMS LIGHT VERTICAL
2503		FORMS HEAVY VERTICAL
2504		FORMS LIGHT TRIPLE DASH HORIZONTAL
2505		FORMS HEAVY TRIPLE DASH HORIZONTAL
2506		FORMS LIGHT TRIPLE DASH VERTICAL
2507		FORMS HEAVY TRIPLE DASH VERTICAL
2508		FORMS LIGHT QUADRUPLE DASH HORIZONTAL
2509		FORMS HEAVY QUADRUPLE DASH HORIZONTAL
250A		FORMS LIGHT QUADRUPLE DASH VERTICAL
250B		FORMS HEAVY QUADRUPLE DASH VERTICAL
250C		FORMS LIGHT DOWN AND RIGHT
250D		FORMS DOWN LIGHT AND RIGHT HEAVY
250E		FORMS DOWN HEAVY AND RIGHT LIGHT
250F		FORMS HEAVY DOWN AND RIGHT
2510		FORMS LIGHT DOWN AND LEFT
2511		FORMS DOWN LIGHT AND LEFT HEAVY
2512		FORMS DOWN HEAVY AND LEFT LIGHT
2513		FORMS HEAVY DOWN AND LEFT
2514		FORMS LIGHT UP AND RIGHT
2515		FORMS UP LIGHT AND RIGHT HEAVY
2516		FORMS UP HEAVY AND RIGHT LIGHT
2517		FORMS HEAVY UP AND RIGHT
2518		FORMS LIGHT UP AND LEFT
2519		FORMS UP LIGHT AND LEFT HEAVY
251A		FORMS UP HEAVY AND LEFT LIGHT
251B		FORMS HEAVY UP AND LEFT
251C		FORMS LIGHT VERTICAL AND RIGHT
251D		FORMS VERTICAL LIGHT AND RIGHT HEAVY
251E		FORMS UP HEAVY AND RIGHT DOWN LIGHT
251F		FORMS DOWN HEAVY AND RIGHT UP LIGHT
2520		FORMS VERTICAL HEAVY AND RIGHT LIGHT
2521		FORMS DOWN LIGHT AND RIGHT UP HEAVY
2522		FORMS UP LIGHT AND RIGHT DOWN HEAVY
2523		FORMS HEAVY VERTICAL AND RIGHT
2524		FORMS LIGHT VERTICAL AND LEFT
2525		FORMS VERTICAL LIGHT AND LEFT HEAVY
2526		FORMS UP HEAVY AND LEFT DOWN LIGHT
2527		FORMS DOWN HEAVY AND LEFT UP LIGHT
2528		FORMS VERTICAL HEAVY AND LEFT LIGHT
2529		FORMS DOWN LIGHT AND LEFT UP HEAVY
252A		FORMS UP LIGHT AND LEFT DOWN HEAVY
252B		FORMS HEAVY VERTICAL AND LEFT
252C		FORMS LIGHT DOWN AND HORIZONTAL
252D		FORMS LEFT HEAVY AND RIGHT DOWN LIGHT
252E		FORMS RIGHT HEAVY AND LEFT DOWN LIGHT
252F		FORMS DOWN LIGHT AND HORIZONTAL HEAVY
2530		FORMS DOWN HEAVY AND HORIZONTAL LIGHT
2531		FORMS RIGHT LIGHT AND LEFT DOWN HEAVY
2532		FORMS LEFT LIGHT AND RIGHT DOWN HEAVY
2533		FORMS HEAVY DOWN AND HORIZONTAL
2534		FORMS LIGHT UP AND HORIZONTAL
2535		FORMS LEFT HEAVY AND RIGHT UP LIGHT
2536		FORMS RIGHT HEAVY AND LEFT UP LIGHT
2537		FORMS UP LIGHT AND HORIZONTAL HEAVY
2538		FORMS UP HEAVY AND HORIZONTAL LIGHT
2539		FORMS RIGHT LIGHT AND LEFT UP HEAVY
253A		FORMS LEFT LIGHT AND RIGHT UP HEAVY
253B		FORMS HEAVY UP AND HORIZONTAL
253C		FORMS LIGHT VERTICAL AND HORIZONTAL
253D		FORMS LEFT HEAVY AND RIGHT VERTICAL LIGHT
253E		FORMS RIGHT HEAVY AND LEFT VERTICAL LIGHT
253F		FORMS VERTICAL LIGHT AND HORIZONTAL HEAVY
2540		FORMS UP HEAVY AND DOWN HORIZONTAL LIGHT
2541		FORMS DOWN HEAVY AND UP HORIZONTAL LIGHT
2542		FORMS VERTICAL HEAVY AND HORIZONTAL LIGHT
2543		FORMS LEFT UP HEAVY AND RIGHT DOWN LIGHT
2544		FORMS RIGHT UP HEAVY AND LEFT DOWN LIGHT
2545		FORMS LEFT DOWN HEAVY AND RIGHT UP LIGHT
2546		FORMS RIGHT DOWN HEAVY AND LEFT UP LIGHT
2547		FORMS DOWN LIGHT AND UP HORIZONTAL HEAVY
2548		FORMS UP LIGHT AND DOWN HORIZONTAL HEAVY
2549		FORMS RIGHT LIGHT AND LEFT VERTICAL HEAVY
254A		FORMS LEFT LIGHT AND RIGHT VERTICAL HEAVY
254B		FORMS HEAVY VERTICAL AND HORIZONTAL
254C		FORMS LIGHT DOUBLE DASH HORIZONTAL
254D		FORMS HEAVY DOUBLE DASH HORIZONTAL
254E		FORMS LIGHT DOUBLE DASH VERTICAL
254F		FORMS HEAVY DOUBLE DASH VERTICAL
2550		FORMS DOUBLE HORIZONTAL
2551		FORMS DOUBLE VERTICAL
2552		FORMS DOWN SINGLE AND RIGHT DOUBLE
2553		FORMS DOWN DOUBLE AND RIGHT SINGLE
2554		FORMS DOUBLE DOWN AND RIGHT
2555		FORMS DOWN SINGLE AND LEFT DOUBLE
2556		FORMS DOWN DOUBLE AND LEFT SINGLE
2557		FORMS DOUBLE DOWN AND LEFT
2558		FORMS UP SINGLE AND RIGHT DOUBLE
2559		FORMS UP DOUBLE AND RIGHT SINGLE
255A		FORMS DOUBLE UP AND RIGHT
255B		FORMS UP SINGLE AND LEFT DOUBLE
255C		FORMS UP DOUBLE AND LEFT SINGLE
255D		FORMS DOUBLE UP AND LEFT
255E		FORMS VERTICAL SINGLE AND RIGHT DOUBLE
255F		FORMS VERTICAL DOUBLE AND RIGHT SINGLE
2560		FORMS DOUBLE VERTICAL AND RIGHT
2561		FORMS VERTICAL SINGLE AND LEFT DOUBLE
2562		FORMS VERTICAL DOUBLE AND LEFT SINGLE
2563		FORMS DOUBLE VERTICAL AND LEFT
2564		FORMS DOWN SINGLE AND HORIZONTAL DOUBLE
2565		FORMS DOWN DOUBLE AND HORIZONTAL SINGLE
2566		FORMS DOUBLE DOWN AND HORIZONTAL
2567		FORMS UP SINGLE AND HORIZONTAL DOUBLE
2568		FORMS UP DOUBLE AND HORIZONTAL SINGLE
2569		FORMS DOUBLE UP AND HORIZONTAL
256A		FORMS VERTICAL SINGLE AND HORIZONTAL DOUBLE
256B		FORMS VERTICAL DOUBLE AND HORIZONTAL SINGLE
256C		FORMS DOUBLE VERTICAL AND HORIZONTAL
256D		FORMS LIGHT ARC DOWN AND RIGHT
256E		FORMS LIGHT ARC DOWN AND LEFT
256F		FORMS LIGHT ARC UP AND LEFT
2570		FORMS LIGHT ARC UP AND RIGHT
2571		FORMS LIGHT DIAGONAL UPPER RIGHT TO LOWER LEFT
2572		FORMS LIGHT DIAGONAL UPPER LEFT TO LOWER RIGHT
2573		FORMS LIGHT DIAGONAL CROSS
2574		FORMS LIGHT LEFT
2575		FORMS LIGHT UP
2576		FORMS LIGHT RIGHT
2577		FORMS LIGHT DOWN
2578		FORMS HEAVY LEFT
2579		FORMS HEAVY UP
257A		FORMS HEAVY RIGHT
257B		FORMS HEAVY DOWN
257C		FORMS LIGHT LEFT AND HEAVY RIGHT
257D		FORMS LIGHT UP AND HEAVY DOWN
257E		FORMS HEAVY LEFT AND LIGHT RIGHT
257F		FORMS HEAVY UP AND LIGHT DOWN
2586		LOWER THREE QUARTER BLOCK
258A		LEFT THREE QUARTER BLOCK
25B2		BLACK UP POINTING TRIANGLE
25B3		WHITE UP POINTING TRIANGLE
25B4		BLACK UP POINTING SMALL TRIANGLE
25B5		WHITE UP POINTING SMALL TRIANGLE
25B6		BLACK RIGHT POINTING TRIANGLE
25B7		WHITE RIGHT POINTING TRIANGLE
25B8		BLACK RIGHT POINTING SMALL TRIANGLE
25B9		WHITE RIGHT POINTING SMALL TRIANGLE
25BA		BLACK RIGHT POINTING POINTER
25BB		WHITE RIGHT POINTING POINTER
25BC		BLACK DOWN POINTING TRIANGLE
25BD		WHITE DOWN POINTING TRIANGLE
25BE		BLACK DOWN POINTING SMALL TRIANGLE
25BF		WHITE DOWN POINTING SMALL TRIANGLE
25C0		BLACK LEFT POINTING TRIANGLE
25C1		WHITE LEFT POINTING TRIANGLE
25C2		BLACK LEFT POINTING SMALL TRIANGLE
25C3		WHITE LEFT POINTING SMALL TRIANGLE
25C4		BLACK LEFT POINTING POINTER
25C5		WHITE LEFT POINTING POINTER
25EC		WHITE UP POINTING TRIANGLE WITH DOT
25ED		UP POINTING TRIANGLE WITH LEFT HALF BLACK
25EE		UP POINTING TRIANGLE WITH RIGHT HALF BLACK
262B		SYMBOL OF IRAN
266B		BARRED EIGHTH NOTES
266C		BARRED SIXTEENTH NOTES
266D		FLAT
266E		NATURAL
266F		SHARP
271B		OPEN CENTER CROSS
271C		HEAVY OPEN CENTER CROSS
272B		OPEN CENTER BLACK STAR
272C		BLACK CENTER WHITE STAR
2732		OPEN CENTER ASTERISK
273C		OPEN CENTER TEARDROP-SPOKED ASTERISK
2742		CIRCLED OPEN CENTER EIGHT POINTED STAR
2776		INVERSE CIRCLED DIGIT ONE
2777		INVERSE CIRCLED DIGIT TWO
2778		INVERSE CIRCLED DIGIT THREE
2779		INVERSE CIRCLED DIGIT FOUR
277A		INVERSE CIRCLED DIGIT FIVE
277B		INVERSE CIRCLED DIGIT SIX
277C		INVERSE CIRCLED DIGIT SEVEN
277D		INVERSE CIRCLED DIGIT EIGHT
277E		INVERSE CIRCLED DIGIT NINE
277F		INVERSE CIRCLED NUMBER TEN
2780		CIRCLED SANS-SERIF DIGIT ONE
2781		CIRCLED SANS-SERIF DIGIT TWO
2782		CIRCLED SANS-SERIF DIGIT THREE
2783		CIRCLED SANS-SERIF DIGIT FOUR
2784		CIRCLED SANS-SERIF DIGIT FIVE
2785		CIRCLED SANS-SERIF DIGIT SIX
2786		CIRCLED SANS-SERIF DIGIT SEVEN
2787		CIRCLED SANS-SERIF DIGIT EIGHT
2788		CIRCLED SANS-SERIF DIGIT NINE
2789		CIRCLED SANS-SERIF NUMBER TEN
278A		INVERSE CIRCLED SANS-SERIF DIGIT ONE
278B		INVERSE CIRCLED SANS-SERIF DIGIT TWO
278C		INVERSE CIRCLED SANS-SERIF DIGIT THREE
278D		INVERSE CIRCLED SANS-SERIF DIGIT FOUR
278E		INVERSE CIRCLED SANS-SERIF DIGIT FIVE
278F		INVERSE CIRCLED SANS-SERIF DIGIT SIX
2790		INVERSE CIRCLED SANS-SERIF DIGIT SEVEN
2791		INVERSE CIRCLED SANS-SERIF DIGIT EIGHT
2792		INVERSE CIRCLED SANS-SERIF DIGIT NINE
2793		INVERSE CIRCLED SANS-SERIF NUMBER TEN
2794		HEAVY WIDE-HEADED RIGHT ARROW
2798		HEAVY LOWER RIGHT ARROW
2799		HEAVY RIGHT ARROW
279A		HEAVY UPPER RIGHT ARROW
279B		DRAFTING POINT RIGHT ARROW
279C		HEAVY ROUND-TIPPED RIGHT ARROW
279D		TRIANGLE-HEADED RIGHT ARROW
279E		HEAVY TRIANGLE-HEADED RIGHT ARROW
279F		DASHED TRIANGLE-HEADED RIGHT ARROW
27A0		HEAVY DASHED TRIANGLE-HEADED RIGHT ARROW
27A1		BLACK RIGHT ARROW
27A2		THREE-D TOP-LIGHTED RIGHT ARROWHEAD
27A3		THREE-D BOTTOM-LIGHTED RIGHT ARROWHEAD
27A4		BLACK RIGHT ARROWHEAD
27A5		HEAVY BLACK CURVED DOWN AND RIGHT ARROW
27A6		HEAVY BLACK CURVED UP AND RIGHT ARROW
27A7		SQUAT BLACK RIGHT ARROW
27A8		HEAVY CONCAVE-POINTED BLACK RIGHT ARROW
27A9		RIGHT-SHADED WHITE RIGHT ARROW
27AA		LEFT-SHADED WHITE RIGHT ARROW
27AB		BACK-TILTED SHADOWED WHITE RIGHT ARROW
27AC		FRONT-TILTED SHADOWED WHITE RIGHT ARROW
27AD		HEAVY LOWER RIGHT-SHADOWED WHITE RIGHT ARROW
27AE		HEAVY UPPER RIGHT-SHADOWED WHITE RIGHT ARROW
27AF		NOTCHED LOWER RIGHT-SHADOWED WHITE RIGHT ARROW
27B1		NOTCHED UPPER RIGHT-SHADOWED WHITE RIGHT ARROW
27B2		CIRCLED HEAVY WHITE RIGHT ARROW
27B3		WHITE-FEATHERED RIGHT ARROW
27B4		BLACK-FEATHERED LOWER RIGHT ARROW
27B5		BLACK-FEATHERED RIGHT ARROW
27B6		BLACK-FEATHERED UPPER RIGHT ARROW
27B7		HEAVY BLACK-FEATHERED LOWER RIGHT ARROW
27B8		HEAVY BLACK-FEATHERED RIGHT ARROW
27B9		HEAVY BLACK-FEATHERED UPPER RIGHT ARROW
27BA		TEARDROP-BARBED RIGHT ARROW
27BB		HEAVY TEARDROP-SHANKED RIGHT ARROW
27BC		WEDGE-TAILED RIGHT ARROW
27BD		HEAVY WEDGE-TAILED RIGHT ARROW
27BE		OPEN-OUTLINED RIGHT ARROW
3002		IDEOGRAPHIC PERIOD
3008		OPENING ANGLE BRACKET
3009		CLOSING ANGLE BRACKET
300A		OPENING DOUBLE ANGLE BRACKET
300B		CLOSING DOUBLE ANGLE BRACKET
300C		OPENING CORNER BRACKET
300D		CLOSING CORNER BRACKET
300E		OPENING WHITE CORNER BRACKET
300F		CLOSING WHITE CORNER BRACKET
3010		OPENING BLACK LENTICULAR BRACKET
3011		CLOSING BLACK LENTICULAR BRACKET
3014		OPENING TORTOISE SHELL BRACKET
3015		CLOSING TORTOISE SHELL BRACKET
3016		OPENING WHITE LENTICULAR BRACKET
3017		CLOSING WHITE LENTICULAR BRACKET
3018		OPENING WHITE TORTOISE SHELL BRACKET
3019		CLOSING WHITE TORTOISE SHELL BRACKET
301A		OPENING WHITE SQUARE BRACKET
301B		CLOSING WHITE SQUARE BRACKET
3099		NON-SPACING KATAKANA-HIRAGANA VOICED SOUND MARK
309A		NON-SPACING KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK
3131		HANGUL LETTER GIYEOG
3132		HANGUL LETTER SSANG GIYEOG
3133		HANGUL LETTER GIYEOG SIOS
3135		HANGUL LETTER NIEUN JIEUJ
3136		HANGUL LETTER NIEUN HIEUH
3137		HANGUL LETTER DIGEUD
3138		HANGUL LETTER SSANG DIGEUD
3139		HANGUL LETTER LIEUL
313A		HANGUL LETTER LIEUL GIYEOG
313B		HANGUL LETTER LIEUL MIEUM
313C		HANGUL LETTER LIEUL BIEUB
313D		HANGUL LETTER LIEUL SIOS
313E		HANGUL LETTER LIEUL TIEUT
313F		HANGUL LETTER LIEUL PIEUP
3140		HANGUL LETTER LIEUL HIEUH
3142		HANGUL LETTER BIEUB
3143		HANGUL LETTER SSANG BIEUB
3144		HANGUL LETTER BIEUB SIOS
3146		HANGUL LETTER SSANG SIOS
3148		HANGUL LETTER JIEUJ
3149		HANGUL LETTER SSANG JIEUJ
314A		HANGUL LETTER CIEUC
314B		HANGUL LETTER KIYEOK
314C		HANGUL LETTER TIEUT
314D		HANGUL LETTER PIEUP
3164		HANGUL CAE OM
3165		HANGUL LETTER SSANG NIEUN
3166		HANGUL LETTER NIEUN DIGEUD
3167		HANGUL LETTER NIEUN SIOS
3168		HANGUL LETTER NIEUN BAN CHI EUM
3169		HANGUL LETTER LIEUL GIYEOG SIOS
316A		HANGUL LETTER LIEUL DIGEUD
316B		HANGUL LETTER LIEUL BIEUB SIOS
316C		HANGUL LETTER LIEUL BAN CHI EUM
316D		HANGUL LETTER LIEUL YEOLIN HIEUH
316E		HANGUL LETTER MIEUM BIEUB
316F		HANGUL LETTER MIEUM SIOS
3170		HANGUL LETTER BIEUB BAN CHI EUM
3171		HANGUL LETTER MIEUM SUN GYEONG EUM
3172		HANGUL LETTER BIEUB GIYEOG
3173		HANGUL LETTER BIEUB DIGEUD
3174		HANGUL LETTER BIEUB SIOS GIYEOG
3175		HANGUL LETTER BIEUB SIOS DIGEUD
3176		HANGUL LETTER BIEUB JIEUJ
3177		HANGUL LETTER BIEUB TIEUT
3178		HANGUL LETTER BIEUB SUN GYEONG EUM
3179		HANGUL LETTER SSANG BIEUB SUN GYEONG EUM
317A		HANGUL LETTER SIOS GIYEOG
317B		HANGUL LETTER SIOS NIEUN
317C		HANGUL LETTER SIOS DIGEUD
317D		HANGUL LETTER SIOS BIEUB
317E		HANGUL LETTER SIOS JIEUJ
317F		HANGUL LETTER BAN CHI EUM
3180		HANGUL LETTER SSANG IEUNG
3181		HANGUL LETTER NGIEUNG
3182		HANGUL LETTER NGIEUNG SIOS
3183		HANGUL LETTER NGIEUNG BAN CHI EUM
3184		HANGUL LETTER PIEUP SUN GYEONG EUM
3185		HANGUL LETTER SSANG HIEUH
3186		HANGUL LETTER YEOLIN HIEUH
3187		HANGUL LETTER YOYA
3188		HANGUL LETTER YOYAE
3189		HANGUL LETTER YOI
318A		HANGUL LETTER YUYEO
318B		HANGUL LETTER YUYE
318C		HANGUL LETTER YUI
318D		HANGUL LETTER ALAE A
318E		HANGUL LETTER ALAE AE
3190		KANBUN TATETEN
3191		KAERITEN RE
3192		KAERITEN ITI
3193		KAERITEN NI
3194		KAERITEN SAN
3195		KAERITEN SI
3196		KAERITEN ZYOU
3197		KAERITEN TYUU
3198		KAERITEN GE
3199		KAERITEN KOU
319A		KAERITEN OTU
319B		KAERITEN HEI
319C		KAERITEN TEI
319D		KAERITEN TEN
319E		KAERITEN TI
319F		KAERITEN ZIN
3200		PARENTHESIZED HANGUL GIYEOG
3202		PARENTHESIZED HANGUL DIGEUD
3203		PARENTHESIZED HANGUL LIEUL
3205		PARENTHESIZED HANGUL BIEUB
3208		PARENTHESIZED HANGUL JIEUJ
3209		PARENTHESIZED HANGUL CIEUC
320A		PARENTHESIZED HANGUL KIYEOK
320B		PARENTHESIZED HANGUL TIEUT
320C		PARENTHESIZED HANGUL PIEUP
320E		PARENTHESIZED HANGUL GA
320F		PARENTHESIZED HANGUL NA
3210		PARENTHESIZED HANGUL DA
3211		PARENTHESIZED HANGUL LA
3212		PARENTHESIZED HANGUL MA
3213		PARENTHESIZED HANGUL BA
3214		PARENTHESIZED HANGUL SA
3215		PARENTHESIZED HANGUL A
3216		PARENTHESIZED HANGUL JA
3217		PARENTHESIZED HANGUL CA
3218		PARENTHESIZED HANGUL KA
3219		PARENTHESIZED HANGUL TA
321A		PARENTHESIZED HANGUL PA
321B		PARENTHESIZED HANGUL HA
321C		PARENTHESIZED HANGUL JU
3260		CIRCLED HANGUL GIYEOG
3262		CIRCLED HANGUL DIGEUD
3263		CIRCLED HANGUL LIEUL
3265		CIRCLED HANGUL BIEUB
3268		CIRCLED HANGUL JIEUJ
3269		CIRCLED HANGUL CIEUC
326A		CIRCLED HANGUL KIYEOK
326B		CIRCLED HANGUL TIEUT
326C		CIRCLED HANGUL PIEUP
326E		CIRCLED HANGUL GA
326F		CIRCLED HANGUL NA
3270		CIRCLED HANGUL DA
3271		CIRCLED HANGUL LA
3272		CIRCLED HANGUL MA
3273		CIRCLED HANGUL BA
3274		CIRCLED HANGUL SA
3275		CIRCLED HANGUL A
3276		CIRCLED HANGUL JA
3277		CIRCLED HANGUL CA
3278		CIRCLED HANGUL KA
3279		CIRCLED HANGUL TA
327A		CIRCLED HANGUL PA
327B		CIRCLED HANGUL HA
32A5		CIRCLED IDEOGRAPH CENTER
3300		SQUARED APAATO
3301		SQUARED ARUHUA
3302		SQUARED ANPEA
3303		SQUARED AARU
3304		SQUARED ININGU
3305		SQUARED INTI
3306		SQUARED UON
3307		SQUARED ESUKUUDO
3308		SQUARED EEKAA
3309		SQUARED ONSU
330A		SQUARED OOMU
330B		SQUARED KAIRI
330C		SQUARED KARATTO
330D		SQUARED KARORII
330E		SQUARED GARON
330F		SQUARED GANMA
3310		SQUARED GIGA
3311		SQUARED GINII
3312		SQUARED KYURII
3313		SQUARED GIRUDAA
3314		SQUARED KIRO
3315		SQUARED KIROGURAMU
3316		SQUARED KIROMEETORU
3317		SQUARED KIROWATTO
3318		SQUARED GURAMU
3319		SQUARED GURAMUTON
331A		SQUARED KURUZEIRO
331B		SQUARED KUROONE
331C		SQUARED KEESU
331D		SQUARED KORUNA
331E		SQUARED KOOPO
331F		SQUARED SAIKURU
3320		SQUARED SANTIIMU
3321		SQUARED SIRINGU
3322		SQUARED SENTI
3323		SQUARED SENTO
3324		SQUARED DAASU
3325		SQUARED DESI
3326		SQUARED DORU
3327		SQUARED TON
3328		SQUARED NANO
3329		SQUARED NOTTO
332A		SQUARED HAITU
332B		SQUARED PAASENTO
332C		SQUARED PAATU
332D		SQUARED BAARERU
332E		SQUARED PIASUTORU
332F		SQUARED PIKURU
3330		SQUARED PIKO
3331		SQUARED BIRU
3332		SQUARED HUARADDO
3333		SQUARED HUIITO
3334		SQUARED BUSSYERU
3335		SQUARED HURAN
3336		SQUARED HEKUTAARU
3337		SQUARED PESO
3338		SQUARED PENIHI
3339		SQUARED HERUTU
333A		SQUARED PENSU
333B		SQUARED PEEZI
333C		SQUARED BEETA
333D		SQUARED POINTO
333E		SQUARED BORUTO
333F		SQUARED HON
3340		SQUARED PONDO
3341		SQUARED HOORU
3342		SQUARED HOON
3343		SQUARED MAIKURO
3344		SQUARED MAIRU
3345		SQUARED MAHHA
3346		SQUARED MARUKU
3347		SQUARED MANSYON
3348		SQUARED MIKURON
3349		SQUARED MIRI
334A		SQUARED MIRIBAARU
334B		SQUARED MEGA
334C		SQUARED MEGATON
334D		SQUARED MEETORU
334E		SQUARED YAADO
334F		SQUARED YAARU
3350		SQUARED YUAN
3351		SQUARED RITTORU
3352		SQUARED RIRA
3353		SQUARED RUPII
3354		SQUARED RUUBURU
3355		SQUARED REMU
3356		SQUARED RENTOGEN
3357		SQUARED WATTO
337B		SQUARED TWO IDEOGRAPHS ERA NAME HEISEI
337C		SQUARED TWO IDEOGRAPHS ERA NAME SYOUWA
337D		SQUARED TWO IDEOGRAPHS ERA NAME TAISYOU
337E		SQUARED TWO IDEOGRAPHS ERA NAME MEIZI
337F		SQUARED FOUR IDEOGRAPHS CORPORATION
3380		SQUARED PA AMPS
3381		SQUARED NA
3382		SQUARED MU A
3383		SQUARED MA
3384		SQUARED KA
3385		SQUARED KB
3386		SQUARED MB
3387		SQUARED GB
3388		SQUARED CAL
3389		SQUARED KCAL
338A		SQUARED PF
338B		SQUARED NF
338C		SQUARED MU F
338D		SQUARED MU G
338E		SQUARED MG
338F		SQUARED KG
3390		SQUARED HZ
3391		SQUARED KHZ
3392		SQUARED MHZ
3393		SQUARED GHZ
3394		SQUARED THZ
3395		SQUARED MU L
3396		SQUARED ML
3397		SQUARED DL
3398		SQUARED KL
3399		SQUARED FM
339A		SQUARED NM
339B		SQUARED MU M
339C		SQUARED MM
339D		SQUARED CM
339E		SQUARED KM
339F		SQUARED MM SQUARED
33A0		SQUARED CM SQUARED
33A1		SQUARED M SQUARED
33A2		SQUARED KM SQUARED
33A3		SQUARED MM CUBED
33A4		SQUARED CM CUBED
33A5		SQUARED M CUBED
33A6		SQUARED KM CUBED
33A7		SQUARED M OVER S
33A8		SQUARED M OVER S SQUARED
33A9		SQUARED PA
33AA		SQUARED KPA
33AB		SQUARED MPA
33AC		SQUARED GPA
33AD		SQUARED RAD
33AE		SQUARED RAD OVER S
33AF		SQUARED RAD OVER S SQUARED
33B0		SQUARED PS
33B1		SQUARED NS
33B2		SQUARED MU S
33B3		SQUARED MS
33B4		SQUARED PV
33B5		SQUARED NV
33B6		SQUARED MU V
33B7		SQUARED MV
33B8		SQUARED KV
33B9		SQUARED MV MEGA
33BA		SQUARED PW
33BB		SQUARED NW
33BC		SQUARED MU W
33BD		SQUARED MW
33BE		SQUARED KW
33BF		SQUARED MW MEGA
33C0		SQUARED K OHM
33C1		SQUARED M OHM
33C2		SQUARED AM
33C3		SQUARED BQ
33C4		SQUARED CC
33C5		SQUARED CD
33C6		SQUARED C OVER KG
33C7		SQUARED CO
33C8		SQUARED DB
33C9		SQUARED GY
33CA		SQUARED HA
33CB		SQUARED HP
33CC		SQUARED IN
33CD		SQUARED KK
33CE		SQUARED KM CAPITAL
33CF		SQUARED KT
33D0		SQUARED LM
33D1		SQUARED LN
33D2		SQUARED LOG
33D3		SQUARED LX
33D4		SQUARED MB SMALL
33D5		SQUARED MIL
33D6		SQUARED MOL
33D7		SQUARED PH
33D8		SQUARED PM
33D9		SQUARED PPM
33DA		SQUARED PR
33DB		SQUARED SR
33DC		SQUARED SV
33DD		SQUARED WB
FB1E		HEBREW POINT VARIKA
FDFA		ARABIC LETTER SALLALLAHOU ALAYHE WASALLAM
FDFB		ARABIC LETTER JALLAJALALOUHOU
FE30		GLYPH FOR VERTICAL TWO DOT LEADER
FE31		GLYPH FOR VERTICAL EM DASH
FE32		GLYPH FOR VERTICAL EN DASH
FE33		GLYPH FOR VERTICAL SPACING UNDERSCORE
FE34		GLYPH FOR VERTICAL SPACING WAVY UNDERSCORE
FE35		GLYPH FOR VERTICAL OPENING PARENTHESIS
FE36		GLYPH FOR VERTICAL CLOSING PARENTHESIS
FE37		GLYPH FOR VERTICAL OPENING CURLY BRACKET
FE38		GLYPH FOR VERTICAL CLOSING CURLY BRACKET
FE39		GLYPH FOR VERTICAL OPENING TORTOISE SHELL BRACKET
FE3A		GLYPH FOR VERTICAL CLOSING TORTOISE SHELL BRACKET
FE3B		GLYPH FOR VERTICAL OPENING BLACK LENTICULAR BRACKET
FE3C		GLYPH FOR VERTICAL CLOSING BLACK LENTICULAR BRACKET
FE3D		GLYPH FOR VERTICAL OPENING DOUBLE ANGLE BRACKET
FE3E		GLYPH FOR VERTICAL CLOSING DOUBLE ANGLE BRACKET
FE3F		GLYPH FOR VERTICAL OPENING ANGLE BRACKET
FE40		GLYPH FOR VERTICAL CLOSING ANGLE BRACKET
FE41		GLYPH FOR VERTICAL OPENING CORNER BRACKET
FE42		GLYPH FOR VERTICAL CLOSING CORNER BRACKET
FE43		GLYPH FOR VERTICAL OPENING WHITE CORNER BRACKET
FE44		GLYPH FOR VERTICAL CLOSING WHITE CORNER BRACKET
FE49		SPACING DASHED OVERSCORE
FE4A		SPACING CENTERLINE OVERSCORE
FE4B		SPACING WAVY OVERSCORE
FE4C		SPACING DOUBLE WAVY OVERSCORE
FE4D		SPACING DASHED UNDERSCORE
FE4E		SPACING CENTERLINE UNDERSCORE
FE4F		SPACING WAVY UNDERSCORE
FE52		SMALL PERIOD
FE59		SMALL OPENING PARENTHESIS
FE5A		SMALL CLOSING PARENTHESIS
FE5B		SMALL OPENING CURLY BRACKET
FE5C		SMALL CLOSING CURLY BRACKET
FE5D		SMALL OPENING TORTOISE SHELL BRACKET
FE5E		SMALL CLOSING TORTOISE SHELL BRACKET
FE68		SMALL BACKSLASH
FE70		ARABIC SPACING FATHATAN
FE71		ARABIC FATHATAN ON TATWEEL
FE72		ARABIC SPACING DAMMATAN
FE74		ARABIC SPACING KASRATAN
FE76		ARABIC SPACING FATHAH
FE77		ARABIC FATHAH ON TATWEEL
FE78		ARABIC SPACING DAMMAH
FE79		ARABIC DAMMAH ON TATWEEL
FE7A		ARABIC SPACING KASRAH
FE7B		ARABIC KASRAH ON TATWEEL
FE7C		ARABIC SPACING SHADDAH
FE7D		ARABIC SHADDAH ON TATWEEL
FE7E		ARABIC SPACING SUKUN
FE7F		ARABIC SUKUN ON TATWEEL
FE80		GLYPH FOR ISOLATE ARABIC HAMZAH
FE81		GLYPH FOR ISOLATE ARABIC MADDAH ON ALEF
FE82		GLYPH FOR FINAL ARABIC MADDAH ON ALEF
FE83		GLYPH FOR ISOLATE ARABIC HAMZAH ON ALEF
FE84		GLYPH FOR FINAL ARABIC HAMZAH ON ALEF
FE85		GLYPH FOR ISOLATE ARABIC HAMZAH ON WAW
FE86		GLYPH FOR FINAL ARABIC HAMZAH ON WAW
FE87		GLYPH FOR ISOLATE ARABIC HAMZAH UNDER ALEF
FE88		GLYPH FOR FINAL ARABIC HAMZAH UNDER ALEF
FE89		GLYPH FOR ISOLATE ARABIC HAMZAH ON YA
FE8A		GLYPH FOR FINAL ARABIC HAMZAH ON YA
FE8B		GLYPH FOR INITIAL ARABIC HAMZAH ON YA
FE8C		GLYPH FOR MEDIAL ARABIC HAMZAH ON YA
FE8D		GLYPH FOR ISOLATE ARABIC ALEF
FE8E		GLYPH FOR FINAL ARABIC ALEF
FE8F		GLYPH FOR ISOLATE ARABIC BAA
FE90		GLYPH FOR FINAL ARABIC BAA
FE91		GLYPH FOR INITIAL ARABIC BAA
FE92		GLYPH FOR MEDIAL ARABIC BAA
FE93		GLYPH FOR ISOLATE ARABIC TAA MARBUTAH
FE94		GLYPH FOR FINAL ARABIC TAA MARBUTAH
FE95		GLYPH FOR ISOLATE ARABIC TAA
FE96		GLYPH FOR FINAL ARABIC TAA
FE97		GLYPH FOR INITIAL ARABIC TAA
FE98		GLYPH FOR MEDIAL ARABIC TAA
FE99		GLYPH FOR ISOLATE ARABIC THAA
FE9A		GLYPH FOR FINAL ARABIC THAA
FE9B		GLYPH FOR INITIAL ARABIC THAA
FE9C		GLYPH FOR MEDIAL ARABIC THAA
FE9D		GLYPH FOR ISOLATE ARABIC JEEM
FE9E		GLYPH FOR FINAL ARABIC JEEM
FE9F		GLYPH FOR INITIAL ARABIC JEEM
FEA0		GLYPH FOR MEDIAL ARABIC JEEM
FEA1		GLYPH FOR ISOLATE ARABIC HAA
FEA2		GLYPH FOR FINAL ARABIC HAA
FEA3		GLYPH FOR INITIAL ARABIC HAA
FEA4		GLYPH FOR MEDIAL ARABIC HAA
FEA5		GLYPH FOR ISOLATE ARABIC KHAA
FEA6		GLYPH FOR FINAL ARABIC KHAA
FEA7		GLYPH FOR INITIAL ARABIC KHAA
FEA8		GLYPH FOR MEDIAL ARABIC KHAA
FEA9		GLYPH FOR ISOLATE ARABIC DAL
FEAA		GLYPH FOR FINAL ARABIC DAL
FEAB		GLYPH FOR ISOLATE ARABIC THAL
FEAC		GLYPH FOR FINAL ARABIC THAL
FEAD		GLYPH FOR ISOLATE ARABIC RA
FEAE		GLYPH FOR FINAL ARABIC RA
FEAF		GLYPH FOR ISOLATE ARABIC ZAIN
FEB0		GLYPH FOR FINAL ARABIC ZAIN
FEB1		GLYPH FOR ISOLATE ARABIC SEEN
FEB2		GLYPH FOR FINAL ARABIC SEEN
FEB3		GLYPH FOR INITIAL ARABIC SEEN
FEB4		GLYPH FOR MEDIAL ARABIC SEEN
FEB5		GLYPH FOR ISOLATE ARABIC SHEEN
FEB6		GLYPH FOR FINAL ARABIC SHEEN
FEB7		GLYPH FOR INITIAL ARABIC SHEEN
FEB8		GLYPH FOR MEDIAL ARABIC SHEEN
FEB9		GLYPH FOR ISOLATE ARABIC SAD
FEBA		GLYPH FOR FINAL ARABIC SAD
FEBB		GLYPH FOR INITIAL ARABIC SAD
FEBC		GLYPH FOR MEDIAL ARABIC SAD
FEBD		GLYPH FOR ISOLATE ARABIC DAD
FEBE		GLYPH FOR FINAL ARABIC DAD
FEBF		GLYPH FOR INITIAL ARABIC DAD
FEC0		GLYPH FOR MEDIAL ARABIC DAD
FEC1		GLYPH FOR ISOLATE ARABIC TAH
FEC2		GLYPH FOR FINAL ARABIC TAH
FEC3		GLYPH FOR INITIAL ARABIC TAH
FEC4		GLYPH FOR MEDIAL ARABIC TAH
FEC5		GLYPH FOR ISOLATE ARABIC DHAH
FEC6		GLYPH FOR FINAL ARABIC DHAH
FEC7		GLYPH FOR INITIAL ARABIC DHAH
FEC8		GLYPH FOR MEDIAL ARABIC DHAH
FEC9		GLYPH FOR ISOLATE ARABIC AIN
FECA		GLYPH FOR FINAL ARABIC AIN
FECB		GLYPH FOR INITIAL ARABIC AIN
FECC		GLYPH FOR MEDIAL ARABIC AIN
FECD		GLYPH FOR ISOLATE ARABIC GHAIN
FECE		GLYPH FOR FINAL ARABIC GHAIN
FECF		GLYPH FOR INITIAL ARABIC GHAIN
FED0		GLYPH FOR MEDIAL ARABIC GHAIN
FED1		GLYPH FOR ISOLATE ARABIC FA
FED2		GLYPH FOR FINAL ARABIC FA
FED3		GLYPH FOR INITIAL ARABIC FA
FED4		GLYPH FOR MEDIAL ARABIC FA
FED5		GLYPH FOR ISOLATE ARABIC QAF
FED6		GLYPH FOR FINAL ARABIC QAF
FED7		GLYPH FOR INITIAL ARABIC QAF
FED8		GLYPH FOR MEDIAL ARABIC QAF
FED9		GLYPH FOR ISOLATE ARABIC CAF
FEDA		GLYPH FOR FINAL ARABIC CAF
FEDB		GLYPH FOR INITIAL ARABIC CAF
FEDC		GLYPH FOR MEDIAL ARABIC CAF
FEDD		GLYPH FOR ISOLATE ARABIC LAM
FEDE		GLYPH FOR FINAL ARABIC LAM
FEDF		GLYPH FOR INITIAL ARABIC LAM
FEE0		GLYPH FOR MEDIAL ARABIC LAM
FEE1		GLYPH FOR ISOLATE ARABIC MEEM
FEE2		GLYPH FOR FINAL ARABIC MEEM
FEE3		GLYPH FOR INITIAL ARABIC MEEM
FEE4		GLYPH FOR MEDIAL ARABIC MEEM
FEE5		GLYPH FOR ISOLATE ARABIC NOON
FEE6		GLYPH FOR FINAL ARABIC NOON
FEE7		GLYPH FOR INITIAL ARABIC NOON
FEE8		GLYPH FOR MEDIAL ARABIC NOON
FEE9		GLYPH FOR ISOLATE ARABIC HA
FEEA		GLYPH FOR FINAL ARABIC HA
FEEB		GLYPH FOR INITIAL ARABIC HA
FEEC		GLYPH FOR MEDIAL ARABIC HA
FEED		GLYPH FOR ISOLATE ARABIC WAW
FEEE		GLYPH FOR FINAL ARABIC WAW
FEEF		GLYPH FOR ISOLATE ARABIC ALEF MAQSURAH
FEF0		GLYPH FOR FINAL ARABIC ALEF MAQSURAH
FEF1		GLYPH FOR ISOLATE ARABIC YA
FEF2		GLYPH FOR FINAL ARABIC YA
FEF3		GLYPH FOR INITIAL ARABIC YA
FEF4		GLYPH FOR MEDIAL ARABIC YA
FEF5		GLYPH FOR ISOLATE ARABIC MADDAH ON LIGATURE LAM ALEF
FEF6		GLYPH FOR FINAL ARABIC MADDAH ON LIGATURE LAM ALEF
FEF7		GLYPH FOR ISOLATE ARABIC HAMZAH ON LIGATURE LAM ALEF
FEF8		GLYPH FOR FINAL ARABIC HAMZAH ON LIGATURE LAM ALEF
FEF9		GLYPH FOR ISOLATE ARABIC HAMZAH UNDER LIGATURE LAM ALEF
FEFA		GLYPH FOR FINAL ARABIC HAMZAH UNDER LIGATURE LAM ALEF
FEFB		GLYPH FOR ISOLATE ARABIC LIGATURE LAM ALEF
FEFC		GLYPH FOR FINAL ARABIC LIGATURE LAM ALEF
FEFF		BYTE ORDER MARK
FF08		FULLWIDTH OPENING PARENTHESIS
FF09		FULLWIDTH CLOSING PARENTHESIS
FF0E		FULLWIDTH PERIOD
FF0F		FULLWIDTH SLASH
FF3B		FULLWIDTH OPENING SQUARE BRACKET
FF3C		FULLWIDTH BACKSLASH
FF3D		FULLWIDTH CLOSING SQUARE BRACKET
FF3E		FULLWIDTH SPACING CIRCUMFLEX
FF3F		FULLWIDTH SPACING UNDERSCORE
FF40		FULLWIDTH SPACING GRAVE
FF5B		FULLWIDTH OPENING CURLY BRACKET
FF5C		FULLWIDTH VERTICAL BAR
FF5D		FULLWIDTH CLOSING CURLY BRACKET
FF5E		FULLWIDTH SPACING TILDE
FF61		HALFWIDTH IDEOGRAPHIC PERIOD
FF62		HALFWIDTH OPENING CORNER BRACKET
FF63		HALFWIDTH CLOSING CORNER BRACKET
FFA0		HALFWIDTH HANGUL CAE OM
FFA1		HALFWIDTH HANGUL LETTER GIYEOG
FFA2		HALFWIDTH HANGUL LETTER SSANG GIYEOG
FFA3		HALFWIDTH HANGUL LETTER GIYEOG SIOS
FFA5		HALFWIDTH HANGUL LETTER NIEUN JIEUJ
FFA6		HALFWIDTH HANGUL LETTER NIEUN HIEUH
FFA7		HALFWIDTH HANGUL LETTER DIGEUD
FFA8		HALFWIDTH HANGUL LETTER SSANG DIGEUD
FFA9		HALFWIDTH HANGUL LETTER LIEUL
FFAA		HALFWIDTH HANGUL LETTER LIEUL GIYEOG
FFAB		HALFWIDTH HANGUL LETTER LIEUL MIEUM
FFAC		HALFWIDTH HANGUL LETTER LIEUL BIEUB
FFAD		HALFWIDTH HANGUL LETTER LIEUL SIOS
FFAE		HALFWIDTH HANGUL LETTER LIEUL TIEUT
FFAF		HALFWIDTH HANGUL LETTER LIEUL PIEUP
FFB0		HALFWIDTH HANGUL LETTER LIEUL HIEUH
FFB2		HALFWIDTH HANGUL LETTER BIEUB
FFB3		HALFWIDTH HANGUL LETTER SSANG BIEUB
FFB4		HALFWIDTH HANGUL LETTER BIEUB SIOS
FFB6		HALFWIDTH HANGUL LETTER SSANG SIOS
FFB8		HALFWIDTH HANGUL LETTER JIEUJ
FFB9		HALFWIDTH HANGUL LETTER SSANG JIEUJ
FFBA		HALFWIDTH HANGUL LETTER CIEUC
FFBB		HALFWIDTH HANGUL LETTER KIYEOK
FFBC		HALFWIDTH HANGUL LETTER TIEUT
FFBD		HALFWIDTH HANGUL LETTER PIEUP
FFE3		FULLWIDTH SPACING MACRON
FFE4		FULLWIDTH BROKEN VERTICAL BAR
END
